@@ -18,7 +18,7 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: jacobi.c,v 1.3 2000/05/04 11:25:02 bjg Exp $
+ * RCS:     $Id: jacobi.c,v 1.6 2001/05/11 12:59:44 bjg Exp $
  */
 /* Simple linear algebra operations, operating directly
  * on the gsl_vector and gsl_matrix objects. These are
@@ -40,7 +40,7 @@
 
 inline static void
 jac_rotate(gsl_matrix * a,
-           int i, int j, int k, int l,
+           unsigned int i, unsigned int j, unsigned int k, unsigned int l,
            double * g, double * h,
            double s, double tau)
 {
@@ -51,16 +51,13 @@ jac_rotate(gsl_matrix * a,
 }
 
 int
-gsl_eigen_jacobi_impl(gsl_matrix * a,
+gsl_eigen_jacobi(gsl_matrix * a,
                          gsl_vector * eval,
                          gsl_matrix * evec,
                          unsigned int max_rot, 
                          unsigned int * nrot)
 {
-  if(a == 0 || eval == 0 || evec == 0) {
-    return GSL_EFAULT;
-  }
-  else if(a->size1 != a->size2) {
+  if(a->size1 != a->size2) {
     return GSL_ENOTSQR;
   }
   else if(a->size1 != evec->size1 || a->size1 != evec->size2) {
@@ -70,9 +67,8 @@ gsl_eigen_jacobi_impl(gsl_matrix * a,
     return GSL_EBADLEN;
   }
   else {
-    const int n = a->size1;
-    unsigned int i;
-    int j, iq, ip;
+    const unsigned int n = a->size1;
+    unsigned int i, j, iq, ip;
     double t, s;
 
     REAL * b = (REAL *) malloc(n * sizeof(REAL));
@@ -155,10 +151,10 @@ gsl_eigen_jacobi_impl(gsl_matrix * a,
 	    gsl_vector_set(eval, iq, d_iq + h);
 	    gsl_matrix_set(a, ip, iq, 0.0);
 
-            for(j=0; j<=ip-1; j++){
+            for(j=0; j<ip; j++){
               jac_rotate(a, j, ip, j, iq, &g, &h, s, tau);
             }
-            for(j=ip+1; j<=iq-1; j++){
+            for(j=ip+1; j<iq; j++){
               jac_rotate(a, ip, j, j, iq, &g, &h, s, tau);
             }
             for(j=iq+1; j<n; j++){
@@ -185,23 +181,20 @@ gsl_eigen_jacobi_impl(gsl_matrix * a,
 }
 
 int
-gsl_eigen_invert_jacobi_impl(const gsl_matrix * a,
+gsl_eigen_invert_jacobi(const gsl_matrix * a,
                              gsl_matrix * ainv,
                              unsigned int max_rot)
 {
-  if(a == 0 || ainv == 0) {
-    return GSL_EFAULT;
-  }
-  else if(a->size1 != a->size2 || ainv->size1 != ainv->size2) {
+  if(a->size1 != a->size2 || ainv->size1 != ainv->size2) {
     return GSL_ENOTSQR;
   }
   else if(a->size1 != ainv->size2) {
     return GSL_EBADLEN;
   }
   else {
-    const int n = a->size1;
+    const unsigned int n = a->size1;
     unsigned int nrot;
-    int i,j,k,l;
+    unsigned int i,j,k,l;
 
     /* This is annoying because I do not want
      * the error handling in these functions.
@@ -221,7 +214,7 @@ gsl_eigen_invert_jacobi_impl(const gsl_matrix * a,
 
     memcpy(ainv->data, a->data, n*n*sizeof(REAL));
 
-    gsl_eigen_jacobi_impl(ainv, eval, evec, max_rot, &nrot);
+    gsl_eigen_jacobi(ainv, eval, evec, max_rot, &nrot);
 
     for(i=0; i<n; i++) {
       if(fabs(gsl_vector_get(eval, i)) < 100.0 * GSL_DBL_EPSILON) {
