@@ -18,11 +18,12 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: test.c,v 1.8 2000/05/15 19:39:13 bjg Exp $
+ * RCS:     $Id: test.c,v 1.12 2001/05/06 18:09:48 bjg Exp $
  */
+#include <config.h>
 #include <gsl/gsl_test.h>
 #include <gsl/gsl_math.h>
-#include <gsl/gsl_linalg.h>
+#include <gsl/gsl_blas.h>
 #include <gsl/gsl_ieee_utils.h>
 #include "gsl_eigen.h"
 
@@ -43,7 +44,7 @@ int test_eigen_jacobi(void)
 {
   int s = 0;
 
-  int nrot;
+  unsigned int nrot;
   gsl_matrix * evec = gsl_matrix_alloc(10, 10);
   gsl_vector * eval = gsl_vector_alloc(10);
 
@@ -62,8 +63,8 @@ int test_eigen_jacobi(void)
 
   /* 10x10 Hilbert matrix */
   gsl_matrix * hm = create_hilbert_matrix(10);
-  gsl_eigen_jacobi_impl(hm, eval, evec, 1000, &nrot);
-  gsl_eigen_sort_impl(eval, evec, GSL_EIGEN_SORT_VALUE);
+  gsl_eigen_jacobi(hm, eval, evec, 1000, &nrot);
+  gsl_eigen_sort(eval, evec, GSL_EIGEN_SORT_VALUE);
 
   s += ( fabs(eval_h10[0] - eval->data[9]) > 1.0e-15 );
   s += ( fabs(eval_h10[1] - eval->data[8]) > 1.0e-14 );
@@ -90,9 +91,10 @@ int test_invert_jacobi(void)
 
   /* 10x10 Hilbert matrix */
   gsl_matrix * hm = create_hilbert_matrix(10);
-  gsl_eigen_invert_jacobi_impl(hm, hminv, 1000);
+  gsl_eigen_invert_jacobi(hm, hminv, 1000);
 
-  gsl_linalg_matmult(hm, hminv, id);
+  /* gsl_linalg_matmult(hm, hminv, id); */
+  gsl_blas_dgemm (CblasNoTrans, CblasNoTrans, 1.0, hm, hminv, 0.0, id);
 
   for(i=0; i<10; i++) {
     for(j=0; j<10; j++) {
