@@ -63,12 +63,14 @@ enum {
   GSL_EDIVERGE = 22,  /* integral or series is divergent */
   GSL_EUNSUP   = 23,  /* requested feature is not supported by the hardware */
   GSL_EUNIMPL  = 24,  /* requested feature not (yet) implemented */
-  GSL_ECACHE   = 25,  /* cache table limit exceeded */
-  GSL_ENOPROG  = 26,  /* iteration is not making progress towards solution */
-  GSL_ENOPROGJ = 27,  /* jacobian evaluations are not improving the solution */
-  GSL_ETOLF    = 28,  /* cannot reach the specified tolerance in F */
-  GSL_ETOLX    = 29,  /* cannot reach the specified tolerance in X */
-  GSL_ETOLG    = 30   /* cannot reach the specified tolerance in gradient */
+  GSL_ECACHE   = 25,  /* cache limit exceeded */
+  GSL_ETABLE   = 26,  /* table limit exceeded */
+  GSL_ENOPROG  = 27,  /* iteration is not making progress towards solution */
+  GSL_ENOPROGJ = 28,  /* jacobian evaluations are not improving the solution */
+  GSL_ETOLF    = 29,  /* cannot reach the specified tolerance in F */
+  GSL_ETOLX    = 30,  /* cannot reach the specified tolerance in X */
+  GSL_ETOLG    = 31,  /* cannot reach the specified tolerance in gradient */
+  GSL_EOF      = 32   /* end of file */
 } ;
 
 void gsl_error (const char * reason, const char * file, int line,
@@ -91,6 +93,9 @@ typedef void gsl_stream_handler_t (const char * label, const char * file,
 gsl_error_handler_t * 
 gsl_set_error_handler (gsl_error_handler_t * new_handler);
 
+gsl_error_handler_t *
+gsl_set_error_handler_off (void);
+
 gsl_stream_handler_t * 
 gsl_set_stream_handler (gsl_stream_handler_t * new_handler);
 
@@ -121,6 +126,11 @@ FILE * gsl_set_stream (FILE * new_stream);
        return ; \
        } while (0)
 
+/* GSL_ERROR_NULL suitable for out-of-memory conditions */
+
+#define GSL_ERROR_NULL(reason, gsl_errno) GSL_ERROR_VAL(reason, gsl_errno, 0)
+
+
 /* GSL library code can occasionally generate warnings, which are not
    intended to be fatal. You can compile a version of the library with
    warnings turned off globally by defining the preprocessor constant
