@@ -36,38 +36,38 @@ FUNCTION(fft_real,pass_n) (const BASE in[],
   size_t e1, e2;
 
   const double d_theta = 2.0 * M_PI / ((double) factor);
-  const double cos_d_theta = cos (d_theta);
-  const double sin_d_theta = sin (d_theta);
+  const ATOMIC cos_d_theta = cos (d_theta);
+  const ATOMIC sin_d_theta = sin (d_theta);
 
   for (k1 = 0; k1 < q; k1++)
     {
       /* compute x = W(factor) z, for z real */
 
-      double dw_real = 1.0, dw_imag = 0.0;
+      ATOMIC dw_real = 1.0, dw_imag = 0.0;
 
       for (e1 = 0; e1 <= factor - e1; e1++)
 	{
-	  double sum_real = 0.0;
-	  double sum_imag = 0.0;
+	  ATOMIC sum_real = 0.0;
+	  ATOMIC sum_imag = 0.0;
 
-	  double w_real = 1.0, w_imag = 0.0;
+	  ATOMIC w_real = 1.0, w_imag = 0.0;
 
 	  if (e1 > 0)
 	    {
-	      double tmp_real = dw_real * cos_d_theta + dw_imag * sin_d_theta;
-	      double tmp_imag = -dw_real * sin_d_theta + dw_imag * cos_d_theta;
+	      ATOMIC tmp_real = dw_real * cos_d_theta + dw_imag * sin_d_theta;
+	      ATOMIC tmp_imag = -dw_real * sin_d_theta + dw_imag * cos_d_theta;
 	      dw_real = tmp_real;
 	      dw_imag = tmp_imag;
 	    }
 
 	  for (e2 = 0; e2 < factor; e2++)
 	    {
-	      double z_real = VECTOR(in,istride,k1 * product_1 + e2 * m);
+	      ATOMIC z_real = VECTOR(in,istride,k1 * product_1 + e2 * m);
 
 	      if (e2 > 0)
 		{
-		  double tmp_real = dw_real * w_real - dw_imag * w_imag;
-		  double tmp_imag = dw_real * w_imag + dw_imag * w_real;
+		  ATOMIC tmp_real = dw_real * w_real - dw_imag * w_imag;
+		  ATOMIC tmp_imag = dw_real * w_imag + dw_imag * w_real;
 		  w_real = tmp_real;
 		  w_imag = tmp_imag;
 		}
@@ -104,18 +104,18 @@ FUNCTION(fft_real,pass_n) (const BASE in[],
       for (k1 = 0; k1 < q; k1++)
 	{
 
-	  double dw_real = 1.0, dw_imag = 0.0;
+	  ATOMIC dw_real = 1.0, dw_imag = 0.0;
 
 	  for (e1 = 0; e1 < factor; e1++)
 	    {
-	      double sum_real = 0.0, sum_imag = 0.0;
+	      ATOMIC sum_real = 0.0, sum_imag = 0.0;
 
-	      double w_real = 1.0, w_imag = 0.0;
+	      ATOMIC w_real = 1.0, w_imag = 0.0;
 
 	      if (e1 > 0)
 		{
-		  const double tmp_real = dw_real * cos_d_theta + dw_imag * sin_d_theta;
-		  const double tmp_imag = -dw_real * sin_d_theta + dw_imag * cos_d_theta;
+		  const ATOMIC tmp_real = dw_real * cos_d_theta + dw_imag * sin_d_theta;
+		  const ATOMIC tmp_imag = -dw_real * sin_d_theta + dw_imag * cos_d_theta;
 		  dw_real = tmp_real;
 		  dw_imag = tmp_imag;
 		}
@@ -125,8 +125,8 @@ FUNCTION(fft_real,pass_n) (const BASE in[],
 
 		  int tskip = (product_1 + 1) / 2 - 1;
 		  const size_t from0 = k1 * product_1 + 2 * k + e2 * m - 1;
-		  double tw_real, tw_imag;
-		  double z_real, z_imag;
+		  ATOMIC tw_real, tw_imag;
+		  ATOMIC z_real, z_imag;
 
 		  if (e2 == 0)
 		    {
@@ -141,8 +141,8 @@ FUNCTION(fft_real,pass_n) (const BASE in[],
 		    }
 
 		  {
-		    const double f0_real = VECTOR(in,istride,from0);
-		    const double f0_imag = VECTOR(in,istride,from0 + 1);
+		    const ATOMIC f0_real = VECTOR(in,istride,from0);
+		    const ATOMIC f0_imag = VECTOR(in,istride,from0 + 1);
 
 		    z_real = tw_real * f0_real - tw_imag * f0_imag;
 		    z_imag = tw_real * f0_imag + tw_imag * f0_real;
@@ -150,8 +150,8 @@ FUNCTION(fft_real,pass_n) (const BASE in[],
 
 		  if (e2 > 0)
 		    {
-		      const double tmp_real = dw_real * w_real - dw_imag * w_imag;
-		      const double tmp_imag = dw_real * w_imag + dw_imag * w_real;
+		      const ATOMIC tmp_real = dw_real * w_real - dw_imag * w_imag;
+		      const ATOMIC tmp_imag = dw_real * w_imag + dw_imag * w_real;
 		      w_real = tmp_real;
 		      w_imag = tmp_imag;
 		    }
@@ -183,27 +183,27 @@ FUNCTION(fft_real,pass_n) (const BASE in[],
 
   {
     double tw_arg = M_PI / ((double) factor);
-    double cos_tw_arg = cos (tw_arg);
-    double sin_tw_arg = -sin (tw_arg);
+    ATOMIC cos_tw_arg = cos (tw_arg);
+    ATOMIC sin_tw_arg = -sin (tw_arg);
 
     for (k1 = 0; k1 < q; k1++)
       {
-	double dw_real = 1.0, dw_imag = 0.0;
+	ATOMIC dw_real = 1.0, dw_imag = 0.0;
 
 	for (e1 = 0; e1 < factor; e1++)
 	  {
-	    double z_real, z_imag;
+	    ATOMIC z_real, z_imag;
 
-	    double sum_real = 0.0;
-	    double sum_imag = 0.0;
+	    ATOMIC sum_real = 0.0;
+	    ATOMIC sum_imag = 0.0;
 
-	    double w_real = 1.0, w_imag = 0.0;
-	    double tw_real = 1.0, tw_imag = 0.0;
+	    ATOMIC w_real = 1.0, w_imag = 0.0;
+	    ATOMIC tw_real = 1.0, tw_imag = 0.0;
 
 	    if (e1 > 0)
 	      {
-		double t_real = dw_real * cos_d_theta + dw_imag * sin_d_theta;
-		double t_imag = -dw_real * sin_d_theta + dw_imag * cos_d_theta;
+		ATOMIC t_real = dw_real * cos_d_theta + dw_imag * sin_d_theta;
+		ATOMIC t_imag = -dw_real * sin_d_theta + dw_imag * cos_d_theta;
 		dw_real = t_real;
 		dw_imag = t_imag;
 	      }
@@ -213,16 +213,16 @@ FUNCTION(fft_real,pass_n) (const BASE in[],
 
 		if (e2 > 0)
 		  {
-		    double tmp_real = tw_real * cos_tw_arg - tw_imag * sin_tw_arg;
-		    double tmp_imag = tw_real * sin_tw_arg + tw_imag * cos_tw_arg;
+		    ATOMIC tmp_real = tw_real * cos_tw_arg - tw_imag * sin_tw_arg;
+		    ATOMIC tmp_imag = tw_real * sin_tw_arg + tw_imag * cos_tw_arg;
 		    tw_real = tmp_real;
 		    tw_imag = tmp_imag;
 		  }
 
 		if (e2 > 0)
 		  {
-		    double tmp_real = dw_real * w_real - dw_imag * w_imag;
-		    double tmp_imag = dw_real * w_imag + dw_imag * w_real;
+		    ATOMIC tmp_real = dw_real * w_real - dw_imag * w_imag;
+		    ATOMIC tmp_imag = dw_real * w_imag + dw_imag * w_real;
 		    w_real = tmp_real;
 		    w_imag = tmp_imag;
 		  }
@@ -230,7 +230,7 @@ FUNCTION(fft_real,pass_n) (const BASE in[],
 
 		{
 		  const size_t from0 = k1 * product_1 + 2 * k + e2 * m - 1;
-		  const double f0_real = VECTOR(in,istride,from0);
+		  const ATOMIC f0_real = VECTOR(in,istride,from0);
 		  z_real = tw_real * f0_real;
 		  z_imag = tw_imag * f0_real;
 		}
