@@ -90,9 +90,11 @@
 #define M_EULER    0.57721566490153286060651209008	/* Euler constant */
 #endif
 
-/* magic constants; mostly for the benefit of the implementation */
+#include <gsl/gsl_sys.h>
 #include <gsl/gsl_machine.h>
 #include <gsl/gsl_precision.h>
+#include <gsl/gsl_nan.h>
+#include <gsl/gsl_pow_int.h>
 
 #undef __BEGIN_DECLS
 #undef __END_DECLS
@@ -113,8 +115,7 @@ __BEGIN_DECLS
 #define GSL_SIGN(x)    ((x) >= 0.0 ? 1 : -1)
 
 /* Return nonzero if x is a real number, i.e. non NaN or infinite. */
-/* FIXME: Is this correct way to check if something is real? */
-#define GSL_IS_REAL(x) (0 * (x) == 0)
+#define GSL_IS_REAL(x) (gsl_finite(x))
 
 /* Define MAX and MIN macros/functions if they don't exist. */
 
@@ -176,11 +177,6 @@ GSL_MIN_LDBL (long double a, long double b)
 #define GSL_MIN_LDBL(a,b)  GSL_MIN(a,b)
 #endif /* HAVE_INLINE */
 
-/* Functions from sys directory */
-double gsl_log1p (const double x);
-double gsl_hypot (const double x, const double y);
-
-
 /* Definition of an arbitrary function with parameters */
 
 struct gsl_function_struct 
@@ -233,20 +229,6 @@ struct gsl_interval_struct
 
 typedef struct gsl_interval_struct gsl_interval;
 
-#ifdef NAN
-#define GSL_NAN NAN
-#define GSL_POSINF HUGE_VAL
-#define GSL_NEGINF (-HUGE_VAL)
-#define GSL_POSZERO (+0)
-#define GSL_NEGZERO (-0)
-#else
-#define GSL_NAN (0.0/0.0)
-#define GSL_POSINF (+1.0/0.0)
-#define GSL_NEGINF (-1.0/0.0)
-#define GSL_POSZERO (+0)
-#define GSL_NEGZERO (-0)
-#endif
-
 __END_DECLS
 
 #endif /* __GSL_MATH_H__ */
