@@ -1,7 +1,27 @@
+/* histogram/test2d_resample.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <math.h>
-#include <gsl_histogram2d.h>
-#include <gsl_test.h>
+#include <gsl/gsl_histogram2d.h>
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_ieee_utils.h>
 
 #include "urand.c"
 
@@ -13,9 +33,12 @@ main (void)
   double total = 0;
   size_t N = 200000;
 
-  gsl_histogram2d *h = gsl_histogram2d_calloc_uniform (10, 10,
-						       0.0, 1.0,
-						       0.0, 1.0);
+  gsl_histogram2d *h;
+
+  gsl_ieee_env_setup ();
+
+  h = gsl_histogram2d_calloc_uniform (10, 10, 0.0, 1.0, 0.0, 1.0);
+
   for (i = 0; i < 10; i++)
     {
       for (j = 0; j < 10; j++)
