@@ -8,6 +8,8 @@
 #include "fp-ppclinux.c"
 #elif defined(HAVE_X86LINUX_IEEE_INTERFACE)
 #include "fp-x86linux.c"
+#elif defined(HAVE_HPUX11_IEEE_INTERFACE)
+#include "fp-hpux11.c"
 #elif defined(HAVE_HPUX_IEEE_INTERFACE)
 #include "fp-hpux.c"
 #elif defined(HAVE_SUNOS4_IEEE_INTERFACE)
@@ -22,6 +24,12 @@
 #include "fp-tru64.c"
 #elif defined(HAVE_FREEBSD_IEEE_INTERFACE)
 #include "fp-freebsd.c"
+#elif defined(HAVE_OS2EMX_IEEE_INTERFACE)
+#include "fp-os2emx.c"
+#elif defined(HAVE_NETBSD_IEEE_INTERFACE)
+#include "fp-netbsd.c"
+#elif defined(HAVE_DARWIN_IEEE_INTERFACE)
+#include "fp-darwin.c"
 #else
 #include "fp-unknown.c" 
 #endif
