@@ -18,7 +18,7 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: cspline.c,v 1.19 2000/05/04 11:25:04 bjg Exp $
+ * RCS:     $Id: cspline.c,v 1.22 2001/04/30 12:30:43 bjg Exp $
  */
 #include <config.h>
 #include <stdlib.h>
@@ -32,11 +32,11 @@
 /* cubic spline interpolation object */
 typedef struct
   {
-    int (*eval_impl) (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y);
-    int (*eval_d_impl) (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *dydx);
-    int (*eval_d2_impl) (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *dydx);
-    int (*eval_i_impl) (const struct _gsl_interp_obj_struct *, const double xa[], const double ya[], gsl_interp_accel *, double a, double b, double * result);
-    void (*free) (gsl_interp_obj *);
+    int (*eval) (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y);
+    int (*eval_d) (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *dydx);
+    int (*eval_d2) (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *dydx);
+    int (*eval_i) (const struct _gsl_interp_struct *, const double xa[], const double ya[], gsl_interp_accel *, double a, double b, double * result);
+    void (*free) (gsl_interp *);
     double xmin;
     double xmax;
     size_t size;
@@ -45,32 +45,32 @@ typedef struct
 gsl_interp_cspline;
 
 static
-gsl_interp_obj *
+gsl_interp *
 cspline_natural_create (const double xa[], const double ya[], size_t size);
 
 static
-gsl_interp_obj *
+gsl_interp *
 cspline_periodic_create (const double xa[], const double ya[], size_t size);
 
 static
 void
-cspline_free (gsl_interp_obj * interp);
+cspline_free (gsl_interp * interp);
 
 static
 int
-cspline_eval_impl (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y);
+cspline_eval (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y);
 
 static
 int
-cspline_eval_d_impl (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *dydx);
+cspline_eval_d (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *dydx);
 
 static
 int
-cspline_eval_d2_impl (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *dydx);
+cspline_eval_d2 (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *dydx);
 
 static
 int
-cspline_eval_i_impl (const gsl_interp_obj *, const double xa[], const double ya[], gsl_interp_accel *, double a, double b, double * result);
+cspline_eval_i (const gsl_interp *, const double xa[], const double ya[], gsl_interp_accel *, double a, double b, double * result);
 
 
 /* global cubic spline factory objects */
@@ -95,10 +95,10 @@ cspline_new (const double xa[], size_t size)
   gsl_interp_cspline *interp = (gsl_interp_cspline *) malloc (sizeof (gsl_interp_cspline));
   if (interp != 0)
     {
-      interp->eval_impl = cspline_eval_impl;
-      interp->eval_d_impl = cspline_eval_d_impl;
-      interp->eval_i_impl = cspline_eval_i_impl;
-      interp->eval_d2_impl = cspline_eval_d2_impl;
+      interp->eval = cspline_eval;
+      interp->eval_d = cspline_eval_d;
+      interp->eval_i = cspline_eval_i;
+      interp->eval_d2 = cspline_eval_d2;
       interp->free = cspline_free;
       interp->xmin = xa[0];
       interp->xmax = xa[size - 1];
@@ -134,7 +134,11 @@ cspline_calc_natural (
   gsl_vector * diag = gsl_vector_alloc(sys_size);
   gsl_vector * offdiag = gsl_vector_alloc(sys_size);
 
-  gsl_vector solution_vec = { sys_size, 1, interp->c + 1, 0 };
+  gsl_vector solution_vec;
+  solution_vec.size   = sys_size;
+  solution_vec.stride = 1;
+  solution_vec.data   = interp->c + 1;
+  solution_vec.block  = 0;
 
   if (g == 0 || diag == 0 || offdiag == 0)
     {
@@ -208,7 +212,11 @@ cspline_calc_periodic (
     gsl_vector * g = gsl_vector_alloc(sys_size);
     gsl_vector * diag = gsl_vector_alloc(sys_size);
     gsl_vector * offdiag = gsl_vector_alloc(sys_size);
-    gsl_vector solution_vec = { sys_size, 1, interp->c + 1, 0 };
+    gsl_vector solution_vec;
+    solution_vec.size   = sys_size;
+    solution_vec.stride = 1;
+    solution_vec.data   = interp->c + 1;
+    solution_vec.block  = 0;
 
     if (g == 0 || diag == 0 || offdiag == 0) {
       status = GSL_ENOMEM;
@@ -241,7 +249,7 @@ cspline_calc_periodic (
 
 /* factory method */
 static
-gsl_interp_obj *
+gsl_interp *
 cspline_natural_create (const double x_array[], const double y_array[], size_t size)
 {
   if (size <= 1)
@@ -252,16 +260,16 @@ cspline_natural_create (const double x_array[], const double y_array[], size_t s
       if (interp != 0)
 	{
 	  int status = cspline_calc_natural (interp, x_array, y_array);
-	  if(status != GSL_SUCCESS) interp->free((gsl_interp_obj *)interp);
+	  if(status != GSL_SUCCESS) interp->free((gsl_interp *)interp);
 	}
-      return (gsl_interp_obj *) interp;
+      return (gsl_interp *) interp;
     }
 }
 
 
 /* factory method */
 static
-gsl_interp_obj *
+gsl_interp *
 cspline_periodic_create (const double x_array[], const double y_array[], size_t size)
 {
   if (size <= 1)
@@ -272,16 +280,16 @@ cspline_periodic_create (const double x_array[], const double y_array[], size_t
       if (interp != 0)
 	{
 	  int status = cspline_calc_periodic (interp, x_array, y_array);
-	  if(status != GSL_SUCCESS) interp->free((gsl_interp_obj *)interp);
+	  if(status != GSL_SUCCESS) interp->free((gsl_interp *)interp);
 	}
-      return (gsl_interp_obj *) interp;
+      return (gsl_interp *) interp;
     }
 }
 
 
 static
 void
-cspline_free (gsl_interp_obj * interp_cspline)
+cspline_free (gsl_interp * interp_cspline)
 {
   gsl_interp_cspline *interp = (gsl_interp_cspline *) interp_cspline;
 
@@ -306,7 +314,7 @@ do {                                                         \
 
 static
 int
-cspline_eval_impl (const gsl_interp_obj * cspline_interp,
+cspline_eval (const gsl_interp * cspline_interp,
 		   const double x_array[], const double y_array[],
 		   double x,
 		   gsl_interp_accel * a,
@@ -366,7 +374,7 @@ cspline_eval_impl (const gsl_interp_obj * cspline_interp,
 
 static
 int
-cspline_eval_d_impl (const gsl_interp_obj * cspline_interp,
+cspline_eval_d (const gsl_interp * cspline_interp,
 		     const double x_array[], const double y_array[],
 		     double x,
 		     gsl_interp_accel * a,
@@ -425,7 +433,7 @@ cspline_eval_d_impl (const gsl_interp_obj * cspline_interp,
 
 static
 int
-cspline_eval_d2_impl (const gsl_interp_obj * cspline_interp,
+cspline_eval_d2 (const gsl_interp * cspline_interp,
 		      const double x_array[], const double y_array[],
 		      double x,
 		      gsl_interp_accel * a,
@@ -484,7 +492,7 @@ cspline_eval_d2_impl (const gsl_interp_obj * cspline_interp,
 
 static
 int
-cspline_eval_i_impl (const gsl_interp_obj * cspline_interp,
+cspline_eval_i (const gsl_interp * cspline_interp,
 		     const double x_array[], const double y_array[],
 		     gsl_interp_accel * acc,
                      double a, double b,
