@@ -18,7 +18,7 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: linear.c,v 1.13 2000/05/04 11:25:04 bjg Exp $
+ * RCS:     $Id: linear.c,v 1.15 2001/04/30 12:30:43 bjg Exp $
  */
 #include <config.h>
 #include <stdlib.h>
@@ -29,11 +29,11 @@
 /* linear interpolation object */
 typedef struct
   {
-    int (*eval_impl) (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y);
-    int (*eval_d_impl) (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y_p);
-    int (*eval_d2_impl) (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y_pp);
-    int (*eval_i_impl) (const struct _gsl_interp_obj_struct *, const double xa[], const double ya[], gsl_interp_accel *, double a, double b, double * result);    
-    void (*free) (gsl_interp_obj *);
+    int (*eval) (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y);
+    int (*eval_d) (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y_p);
+    int (*eval_d2) (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y_pp);
+    int (*eval_i) (const struct _gsl_interp_struct *, const double xa[], const double ya[], gsl_interp_accel *, double a, double b, double * result);    
+    void (*free) (gsl_interp *);
     double xmin;
     double xmax;
     size_t size;
@@ -42,28 +42,28 @@ gsl_interp_linear;
 
 
 static
-gsl_interp_obj *
+gsl_interp *
 linear_create (const double xa[], const double ya[], size_t size);
 
 static
 void
-linear_free (gsl_interp_obj * interp);
+linear_free (gsl_interp * interp);
 
 static
 int
-linear_eval_impl (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y);
+linear_eval (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y);
 
 static
 int
-linear_eval_d_impl (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *dydx);
+linear_eval_d (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *dydx);
 
 static
 int
-linear_eval_d2_impl (const gsl_interp_obj *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y_pp);
+linear_eval_d2 (const gsl_interp *, const double xa[], const double ya[], double x, gsl_interp_accel *, double *y_pp);
 
 static
 int
-linear_eval_i_impl (const gsl_interp_obj *, const double xa[], const double ya[], gsl_interp_accel *, double, double, double *);
+linear_eval_i (const gsl_interp *, const double xa[], const double ya[], gsl_interp_accel *, double, double, double *);
 
 
 const gsl_interp_factory gsl_interp_factory_linear =
@@ -75,7 +75,7 @@ const gsl_interp_factory gsl_interp_factory_linear =
 
 
 static
-gsl_interp_obj *
+gsl_interp *
 linear_create (const double x_array[], const double y_array[], size_t size)
 {
   y_array = 0;			/* prevent warning about unused parameter */
@@ -87,23 +87,23 @@ linear_create (const double x_array[], const double y_array[], size_t size)
       gsl_interp_linear *interp = (gsl_interp_linear *) malloc (sizeof (gsl_interp_linear));
       if (interp != 0)
 	{
-	  interp->eval_impl = linear_eval_impl;
-	  interp->eval_d_impl = linear_eval_d_impl;
-	  interp->eval_d2_impl = linear_eval_d2_impl;
-	  interp->eval_i_impl = linear_eval_i_impl;
+	  interp->eval = linear_eval;
+	  interp->eval_d = linear_eval_d;
+	  interp->eval_d2 = linear_eval_d2;
+	  interp->eval_i = linear_eval_i;
 	  interp->free = linear_free;
 	  interp->xmin = x_array[0];
 	  interp->xmax = x_array[size - 1];
 	  interp->size = size;
 	}
-      return (gsl_interp_obj *) interp;
+      return (gsl_interp *) interp;
     }
 }
 
 
 static
 void
-linear_free (gsl_interp_obj * linear_interp)
+linear_free (gsl_interp * linear_interp)
 {
   if (linear_interp != 0)
     free ((gsl_interp_linear *) linear_interp);
@@ -112,7 +112,7 @@ linear_free (gsl_interp_obj * linear_interp)
 
 static
 int
-linear_eval_impl (const gsl_interp_obj * linear_interp,
+linear_eval (const gsl_interp * linear_interp,
 		  const double x_array[], const double y_array[],
 		  double x,
 		  gsl_interp_accel * a,
@@ -168,7 +168,7 @@ linear_eval_impl (const gsl_interp_obj * linear_interp,
 
 static
 int
-linear_eval_d_impl (const gsl_interp_obj * linear_interp,
+linear_eval_d (const gsl_interp * linear_interp,
 		    const double x_array[], const double y_array[],
 		    double x,
 		    gsl_interp_accel * a,
@@ -221,7 +221,7 @@ linear_eval_d_impl (const gsl_interp_obj * linear_interp,
 
 static
 int
-linear_eval_d2_impl (const gsl_interp_obj * linear_interp,
+linear_eval_d2 (const gsl_interp * linear_interp,
 		     const double x_array[], const double y_array[],
 		     double x,
 		     gsl_interp_accel * a,
@@ -243,7 +243,7 @@ linear_eval_d2_impl (const gsl_interp_obj * linear_interp,
 
 static
 int
-linear_eval_i_impl (const gsl_interp_obj * linear_interp,
+linear_eval_i (const gsl_interp * linear_interp,
 		    const double x_array[], const double y_array[],
 		    gsl_interp_accel * acc,
                     double a, double b,
