@@ -19,7 +19,7 @@
 
 
 /* Author:  G. Jungman
- * RCS:     $Id: test.c,v 1.6 2000/10/20 20:08:10 jungman Exp $
+ * RCS:     $Id: test.c,v 1.10 2001/05/15 10:44:54 bjg Exp $
  */
 #include <config.h>
 #include <stddef.h>
@@ -90,6 +90,18 @@ struct _xy_table
     size_t n;
   };
 
+xy_table make_xy_table (double x[], double y[], size_t n);
+
+xy_table
+make_xy_table (double x[], double y[], size_t n)
+{
+  xy_table t;
+  t.x = x;
+  t.y = y;
+  t.n = n;
+  return t;
+}
+
 static int
 test_interp (
   const xy_table * data_table,
@@ -102,8 +114,8 @@ test_interp (
   int status = 0;
   size_t i;
 
-  gsl_interp_accel *a = gsl_interp_accel_new ();
-  gsl_interp_obj *interp = factory->create (data_table->x,
+  gsl_interp_accel *a = gsl_interp_accel_alloc ();
+  gsl_interp *interp = factory->create (data_table->x,
 					    data_table->y,
 					    data_table->n);
 
@@ -114,9 +126,9 @@ test_interp (
       double deriv;
       double integ;
       double diff_y, diff_deriv, diff_integ;
-      gsl_interp_eval_impl (interp, data_table->x, data_table->y, x, a, &y);
-      gsl_interp_eval_deriv_impl (interp, data_table->x, data_table->y, x, a, &deriv);
-      gsl_interp_eval_integ_impl (interp, data_table->x, data_table->y, 0.0, x, a, &integ);
+      gsl_interp_eval_e (interp, data_table->x, data_table->y, x, a, &y);
+      gsl_interp_eval_deriv_e (interp, data_table->x, data_table->y, x, a, &deriv);
+      gsl_interp_eval_integ_e (interp, data_table->x, data_table->y, 0.0, x, a, &integ);
       diff_y = y - test_table->y[i];
       diff_deriv = deriv - test_d_table->y[i];
       diff_integ = integ - test_i_table->y[i];
@@ -126,12 +138,11 @@ test_interp (
     }
 
   gsl_interp_accel_free (a);
-  gsl_interp_obj_free (interp);
+  gsl_interp_free (interp);
 
   return status;
 }
 
-
 static int
 test_linear (void)
 {
@@ -144,10 +155,10 @@ test_linear (void)
   double test_dy[6] = { 1.0, 1.0, 1.0, 1.0, 1.0, 1.0 };
   double test_iy[6] = { 0.0, 0.125, 0.5, 9.0/8.0, 25.0/8.0, 9.0/2.0 };
 
-  xy_table data_table = { data_x, data_y, sizeof (data_x) / sizeof (double) };
-  xy_table test_table = { test_x, test_y, sizeof (test_x) / sizeof (double) };
-  xy_table test_d_table = { test_x, test_dy, sizeof (test_x) / sizeof (double) };
-  xy_table test_i_table = { test_x, test_iy, sizeof (test_x) / sizeof (double) };
+  xy_table data_table = make_xy_table(data_x, data_y, 4);
+  xy_table test_table = make_xy_table(test_x, test_y, 6);
+  xy_table test_d_table = make_xy_table(test_x, test_dy, 6);
+  xy_table test_i_table = make_xy_table(test_x, test_iy, 6);
 
   s = test_interp (&data_table, &gsl_interp_factory_linear, &test_table, &test_d_table, &test_i_table);
   gsl_test (s, "linear interpolation");
@@ -167,10 +178,10 @@ test_cspline_natural (void)
   double test_dy[4] = { 1.0, 1.0, 1.0, 1.0 };
   double test_iy[4] = { 0.0, 0.125, 0.5, 2.0 };
 
-  xy_table data_table = { data_x, data_y, sizeof (data_x) / sizeof (double) };
-  xy_table test_table = { test_x, test_y, sizeof (test_x) / sizeof (double) };
-  xy_table test_d_table = { test_x, test_dy, sizeof (test_x) / sizeof (double) };
-  xy_table test_i_table = { test_x, test_iy, sizeof (test_x) / sizeof (double) };
+  xy_table data_table = make_xy_table(data_x, data_y, 3);
+  xy_table test_table = make_xy_table(test_x, test_y, 4);
+  xy_table test_d_table = make_xy_table(test_x, test_dy, 4);
+  xy_table test_i_table = make_xy_table(test_x, test_iy, 4);
 
   s = test_interp (&data_table, &gsl_interp_factory_cspline_natural, &test_table, &test_d_table, &test_i_table);
   gsl_test (s, "natural cspline interpolation");
@@ -190,10 +201,10 @@ test_akima_natural (void)
   double test_dy[4] = { 1.0, 1.0, 1.0, 1.0 };
   double test_iy[4] = { 0.0, 0.125, 0.5, 2.0 };
 
-  xy_table data_table = { data_x, data_y, sizeof (data_x) / sizeof (double) };
-  xy_table test_table = { test_x, test_y, sizeof (test_x) / sizeof (double) };
-  xy_table test_d_table = { test_x, test_dy, sizeof (test_x) / sizeof (double) };
-  xy_table test_i_table = { test_x, test_iy, sizeof (test_x) / sizeof (double) };
+  xy_table data_table = make_xy_table(data_x, data_y, 5);
+  xy_table test_table = make_xy_table(test_x, test_y, 4);
+  xy_table test_d_table = make_xy_table(test_x, test_dy, 4);
+  xy_table test_i_table = make_xy_table(test_x, test_iy, 4);
 
   s = test_interp (&data_table, &gsl_interp_factory_akima_natural, &test_table, &test_d_table, &test_i_table);
   gsl_test (s, "natural akima interpolation");
