@@ -55,6 +55,12 @@
  *
  * Based on code by Arthur Kosowsky, Rutgers University
  *                  kosowsky@physics.rutgers.edu  
+ *
+ * Another relevant paper is, P.P.M. De Rijk, "A One-Sided Jacobi
+ * Algorithm for computing the singular value decomposition on a
+ * vector computer", SIAM Journal of Scientific and Statistical
+ * Computing, Vol 10, No 2, pp 359-371, March 1989.
+ * 
  */
 
 int
@@ -82,9 +88,9 @@ gsl_linalg_SV_decomp (gsl_matrix * A,
     }
   else
     {
-      const int M = A->size1;
-      const int N = A->size2;
-      int i, j, k;
+      const size_t M = A->size1;
+      const size_t N = A->size2;
+      size_t i, j, k;
 
       /* Initialize the rotation counter and the sweep counter. */
       int count = 1;
@@ -168,7 +174,7 @@ gsl_linalg_SV_decomp (gsl_matrix * A,
 		  else
 		    {
 		      q -= r;
-		      v = gsl_hypot (2.0 * p, q);
+		      v = hypot (2.0 * p, q);
 		      cosine = sqrt ((v + q) / (2.0 * v));
 		      sine = p / (v * cosine);
 		    }
