@@ -18,15 +18,51 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: test.c,v 1.7 2000/09/19 18:51:51 bjg Exp $
+ * RCS:     $Id: test.c,v 1.12 2001/05/17 16:03:14 bjg Exp $
  */
+#include <config.h>
 #include <gsl/gsl_test.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_ieee_utils.h>
 #include <gsl/gsl_permute_vector.h>
+#include <gsl/gsl_blas.h>
 #include "gsl_linalg.h"
 
-static int 
+int check (double x, double actual, double eps);
+gsl_matrix * create_hilbert_matrix(size_t size);
+gsl_matrix * create_general_matrix(size_t size1, size_t size2);
+gsl_matrix * create_vandermonde_matrix(size_t size);
+gsl_matrix * create_moler_matrix(size_t size);
+int test_matmult(void);
+int test_matmult_mod(void);
+int test_LU_solve_dim(const gsl_matrix * m, const double * actual, double eps);
+int test_LU_solve(void);
+int test_QR_solve_dim(const gsl_matrix * m, const double * actual, double eps);
+int test_QR_solve(void);
+int test_QR_lssolve_dim(const gsl_matrix * m, const double * actual, double eps);
+int test_QR_lssolve(void);
+int test_QR_decomp_dim(const gsl_matrix * m, double eps);
+int test_QR_decomp(void);
+int test_QRPT_solve_dim(const gsl_matrix * m, const double * actual, double eps);
+int test_QRPT_solve(void);
+int test_QRPT_decomp_dim(const gsl_matrix * m, double eps);
+int test_QRPT_decomp(void);
+int test_QR_update_dim(const gsl_matrix * m, double eps);
+int test_QR_update(void);
+int test_SV_solve_dim(const gsl_matrix * m, const double * actual, double eps);
+int test_SV_solve(void);
+int test_SV_decomp_dim(const gsl_matrix * m, double eps);
+int test_SV_decomp(void);
+int test_cholesky_solve_dim(const gsl_matrix * m, const double * actual, double eps);
+int test_cholesky_solve(void);
+int test_cholesky_decomp_dim(const gsl_matrix * m, double eps);
+int test_cholesky_decomp(void);
+int test_HH_solve_dim(const gsl_matrix * m, const double * actual, double eps);
+int test_HH_solve(void);
+int test_TD_solve_dim(size_t dim, double d, double od, const double * actual, double eps);
+int test_TD_solve(void);
+
+int 
 check (double x, double actual, double eps)
 {
   if (actual == 0)
@@ -36,9 +72,9 @@ check (double x, double actual, double eps)
 }
 
 gsl_matrix *
-create_hilbert_matrix(int size)
+create_hilbert_matrix(size_t size)
 {
-  int i, j;
+  size_t i, j;
   gsl_matrix * m = gsl_matrix_alloc(size, size);
   for(i=0; i<size; i++) {
     for(j=0; j<size; j++) {
@@ -49,9 +85,9 @@ create_hilbert_matrix(int size)
 }
 
 gsl_matrix *
-create_general_matrix(int size1, int size2)
+create_general_matrix(size_t size1, size_t size2)
 {
-  int i, j;
+  size_t i, j;
   gsl_matrix * m = gsl_matrix_alloc(size1, size2);
   for(i=0; i<size1; i++) {
     for(j=0; j<size2; j++) {
@@ -62,26 +98,26 @@ create_general_matrix(int size1, int size2)
 }
 
 gsl_matrix *
-create_vandermonde_matrix(int size)
+create_vandermonde_matrix(size_t size)
 {
-  int i, j;
+  size_t i, j;
   gsl_matrix * m = gsl_matrix_alloc(size, size);
   for(i=0; i<size; i++) {
     for(j=0; j<size; j++) {
-      gsl_matrix_set(m, i, j, pow(i + 1.0, size - j - 1));
+      gsl_matrix_set(m, i, j, pow(i + 1.0, size - j - 1.0));
     }
   }
   return m;
 }
 
 gsl_matrix *
-create_moler_matrix(int size)
+create_moler_matrix(size_t size)
 {
-  int i, j;
+  size_t i, j;
   gsl_matrix * m = gsl_matrix_alloc(size, size);
   for(i=0; i<size; i++) {
     for(j=0; j<size; j++) {
-      gsl_matrix_set(m, i, j, GSL_MIN(i+1,j+1)-2);
+      gsl_matrix_set(m, i, j, GSL_MIN(i+1,j+1)-2.0);
     }
   }
   return m;
@@ -96,6 +132,8 @@ gsl_matrix * hilb3;
 gsl_matrix * hilb4;
 gsl_matrix * hilb12;
 
+double m53_lssolution[] = {52.5992295702070, -337.7263113752073, 
+                           351.8823436427604};
 double hilb2_solution[] = {-8.0, 18.0} ;
 double hilb3_solution[] = {27.0, -192.0, 210.0};
 double hilb4_solution[] = {-64.0, 900.0, -2520.0, 1820.0};
@@ -119,6 +157,8 @@ double vander12_solution[] = {0.0, 0.0, 0.0, 0.0,
 
 gsl_matrix * moler10;
 
+/* matmult now obsolete */
+#ifdef MATMULT
 int
 test_matmult(void)
 {
@@ -276,9 +316,9 @@ test_matmult_mod(void)
 
   return s;
 }
+#endif
 
-
-static int
+int
 test_LU_solve_dim(const gsl_matrix * m, const double * actual, double eps)
 {
   int s = 0;
@@ -363,7 +403,7 @@ int test_LU_solve(void)
   return s;
 }
 
-static int
+int
 test_QR_solve_dim(const gsl_matrix * m, const double * actual, double eps)
 {
   int s = 0;
@@ -432,7 +472,105 @@ int test_QR_solve(void)
   return s;
 }
 
-static int
+
+int
+test_QR_lssolve_dim(const gsl_matrix * m, const double * actual, double eps)
+{
+  int s = 0;
+  size_t i, M = m->size1, N = m->size2;
+
+  gsl_vector * rhs = gsl_vector_alloc(M);
+  gsl_matrix * qr  = gsl_matrix_alloc(M,N);
+  gsl_vector * d = gsl_vector_alloc(N);
+  gsl_vector * x = gsl_vector_alloc(N);
+  gsl_vector * r = gsl_vector_alloc(M);
+  gsl_vector * res = gsl_vector_alloc(M);
+  gsl_matrix_memcpy(qr,m);
+  for(i=0; i<M; i++) gsl_vector_set(rhs, i, i+1.0);
+  s += gsl_linalg_QR_decomp(qr, d);
+  s += gsl_linalg_QR_lssolve(qr, d, rhs, x, res);
+
+  for(i=0; i<N; i++) {
+    int foo = check(gsl_vector_get(x, i), actual[i], eps);
+    if(foo) {
+      printf("(%3d,%3d)[%d]: %22.18g   %22.18g\n", M, N, i, gsl_vector_get(x, i), actual[i]);
+    }
+    s += foo;
+  }
+
+  /* compute residual r = b - m x */
+  if (M == N) {
+    gsl_vector_set_zero(r);
+  } else {
+    gsl_vector_memcpy(r, rhs);
+    gsl_blas_dgemv(CblasNoTrans, -1.0, m, x, 1.0, r);
+  };
+
+  for(i=0; i<N; i++) {
+    int foo = check(gsl_vector_get(res, i), gsl_vector_get(r,i), sqrt(eps));
+    if(foo) {
+      printf("(%3d,%3d)[%d]: %22.18g   %22.18g\n", M, N, i, gsl_vector_get(res, i), gsl_vector_get(r,i));
+    }
+    s += foo;
+  }
+
+
+  gsl_vector_free(r);
+  gsl_vector_free(res);
+  gsl_vector_free(x);
+  gsl_vector_free(d);
+  gsl_matrix_free(qr);
+  gsl_vector_free(rhs);
+
+  return s;
+}
+
+int test_QR_lssolve(void)
+{
+  int f;
+  int s = 0;
+
+  f = test_QR_lssolve_dim(m53, m53_lssolution, 2 * 64.0 * GSL_DBL_EPSILON);
+  gsl_test(f, "  QR_lssolve m(5,3)");
+  s += f;
+
+  f = test_QR_lssolve_dim(hilb2, hilb2_solution, 2 * 8.0 * GSL_DBL_EPSILON);
+  gsl_test(f, "  QR_lssolve hilbert(2)");
+  s += f;
+
+  f = test_QR_lssolve_dim(hilb3, hilb3_solution, 2 * 64.0 * GSL_DBL_EPSILON);
+  gsl_test(f, "  QR_lssolve hilbert(3)");
+  s += f;
+
+  f = test_QR_lssolve_dim(hilb4, hilb4_solution, 2 * 1024.0 * GSL_DBL_EPSILON);
+  gsl_test(f, "  QR_lssolve hilbert(4)");
+  s += f;
+
+  f = test_QR_lssolve_dim(hilb12, hilb12_solution, 0.5);
+  gsl_test(f, "  QR_lssolve hilbert(12)");
+  s += f;
+
+  f = test_QR_lssolve_dim(vander2, vander2_solution, 8.0 * GSL_DBL_EPSILON);
+  gsl_test(f, "  QR_lssolve vander(2)");
+  s += f;
+
+  f = test_QR_lssolve_dim(vander3, vander3_solution, 64.0 * GSL_DBL_EPSILON);
+  gsl_test(f, "  QR_lssolve vander(3)");
+  s += f;
+
+  f = test_QR_lssolve_dim(vander4, vander4_solution, 1024.0 * GSL_DBL_EPSILON);
+  gsl_test(f, "  QR_lssolve vander(4)");
+  s += f;
+
+  f = test_QR_lssolve_dim(vander12, vander12_solution, 0.05);
+  gsl_test(f, "  QR_lssolve vander(12)");
+  s += f;
+
+  return s;
+}
+
+
+int
 test_QR_decomp_dim(const gsl_matrix * m, double eps)
 {
   int s = 0;
@@ -449,7 +587,8 @@ test_QR_decomp_dim(const gsl_matrix * m, double eps)
   s += gsl_linalg_QR_decomp(qr, d);
   s += gsl_linalg_QR_unpack(qr, d, q, r);
   
-  gsl_linalg_matmult (q, r, a);
+  /* compute a = q r */
+  gsl_blas_dgemm (CblasNoTrans, CblasNoTrans, 1.0, q, r, 0.0, a);
 
   for(i=0; i<M; i++) {
     for(j=0; j<N; j++) {
@@ -519,7 +658,7 @@ int test_QR_decomp(void)
   return s;
 }
 
-static int
+int
 test_QRPT_solve_dim(const gsl_matrix * m, const double * actual, double eps)
 {
   int s = 0;
@@ -592,7 +731,7 @@ int test_QRPT_solve(void)
 }
 
 
-static int
+int
 test_QRPT_decomp_dim(const gsl_matrix * m, double eps)
 {
   int s = 0, signum;
@@ -609,8 +748,10 @@ test_QRPT_decomp_dim(const gsl_matrix * m, double eps)
 
   s += gsl_linalg_QRPT_decomp(qr, d, perm, &signum);
   s += gsl_linalg_QR_unpack(qr, d, q, r);
-  
-  gsl_linalg_matmult (q, r, a);
+
+  /* compute a = q r */
+  gsl_blas_dgemm (CblasNoTrans, CblasNoTrans, 1.0, q, r, 0.0, a);
+
 
   /* Compute QR P^T by permuting the elements of the rows of QR */
 
@@ -689,35 +830,35 @@ int test_QRPT_decomp(void)
 }
 
 
-static int
+int
 test_QR_update_dim(const gsl_matrix * m, double eps)
 {
   int s = 0;
-  size_t i,j,k, dim = m->size1;
+  size_t i,j,k, M = m->size1, N = m->size2;
 
-  gsl_vector * rhs = gsl_vector_alloc(dim);
-  gsl_matrix * qr1  = gsl_matrix_alloc(dim,dim);
-  gsl_matrix * qr2  = gsl_matrix_alloc(dim,dim);
-  gsl_matrix * q1  = gsl_matrix_alloc(dim,dim);
-  gsl_matrix * r1  = gsl_matrix_alloc(dim,dim);
-  gsl_matrix * q2  = gsl_matrix_alloc(dim,dim);
-  gsl_matrix * r2  = gsl_matrix_alloc(dim,dim);
-  gsl_vector * d = gsl_vector_alloc(dim);
-  gsl_vector * solution1 = gsl_vector_alloc(dim);
-  gsl_vector * solution2 = gsl_vector_alloc(dim);
-  gsl_vector * u = gsl_vector_alloc(dim);
-  gsl_vector * v = gsl_vector_alloc(dim);
-  gsl_vector * w = gsl_vector_alloc(dim);
+  gsl_vector * rhs = gsl_vector_alloc(N);
+  gsl_matrix * qr1  = gsl_matrix_alloc(M,N);
+  gsl_matrix * qr2  = gsl_matrix_alloc(M,N);
+  gsl_matrix * q1  = gsl_matrix_alloc(M,M);
+  gsl_matrix * r1  = gsl_matrix_alloc(M,N);
+  gsl_matrix * q2  = gsl_matrix_alloc(M,M);
+  gsl_matrix * r2  = gsl_matrix_alloc(M,N);
+  gsl_vector * d = gsl_vector_alloc(GSL_MIN(M,N));
+  gsl_vector * solution1 = gsl_vector_alloc(N);
+  gsl_vector * solution2 = gsl_vector_alloc(N);
+  gsl_vector * u = gsl_vector_alloc(M);
+  gsl_vector * v = gsl_vector_alloc(N);
+  gsl_vector * w = gsl_vector_alloc(M);
   gsl_matrix_memcpy(qr1,m);
   gsl_matrix_memcpy(qr2,m);
-  for(i=0; i<dim; i++) gsl_vector_set(rhs, i, i+1.0);
-  for(i=0; i<dim; i++) gsl_vector_set(u, i, sin(i+1.0));
-  for(i=0; i<dim; i++) gsl_vector_set(v, i, cos(i+2.0) + sin(i*i+3.0));
+  for(i=0; i<N; i++) gsl_vector_set(rhs, i, i+1.0);
+  for(i=0; i<M; i++) gsl_vector_set(u, i, sin(i+1.0));
+  for(i=0; i<N; i++) gsl_vector_set(v, i, cos(i+2.0) + sin(i*i+3.0));
 
-  for(i=0; i<dim; i++) 
+  for(i=0; i<M; i++) 
     {
       double ui = gsl_vector_get(u, i);
-      for(j=0; j<dim; j++) 
+      for(j=0; j<N; j++) 
         {
           double vj = gsl_vector_get(v, j);
           double qij = gsl_matrix_get(qr1, i, j);
@@ -730,10 +871,10 @@ test_QR_update_dim(const gsl_matrix * m, double eps)
 
   /* compute w = Q^T u */
       
-  for (j = 0; j < dim; j++)
+  for (j = 0; j < M; j++)
     {
       double sum = 0;
-      for (i = 0; i < dim; i++)
+      for (i = 0; i < M; i++)
           sum += gsl_matrix_get (q2, i, j) * gsl_vector_get (u, i);
       gsl_vector_set (w, j, sum);
     }
@@ -742,12 +883,12 @@ test_QR_update_dim(const gsl_matrix * m, double eps)
 
   /* compute qr2 = q2 * r2 */
 
-  for (i = 0; i < dim; i++)
+  for (i = 0; i < M; i++)
     {
-      for (j = 0; j< dim; j++)
+      for (j = 0; j< N; j++)
         {
           double sum = 0;
-          for (k = 0; k <= j; k++)
+          for (k = 0; k <= GSL_MIN(j,M-1); k++)
             {
               double qik = gsl_matrix_get(q2, i, k);
               double rkj = gsl_matrix_get(r2, k, j);
@@ -757,14 +898,14 @@ test_QR_update_dim(const gsl_matrix * m, double eps)
         }
     }
 
-  for(i=0; i<dim; i++) {
-    for(j=0; j<dim; j++) {
+  for(i=0; i<M; i++) {
+    for(j=0; j<N; j++) {
       double s1 = gsl_matrix_get(qr1, i, j);
       double s2 = gsl_matrix_get(qr2, i, j);
       
       int foo = check(s1, s2, eps);
       if(foo) {
-        printf("%3d[%d,%d]: %22.18g   %22.18g\n", dim, i,j, s1, s2);
+        printf("(%3d,%3d)[%d,%d]: %22.18g   %22.18g\n", M, N, i,j, s1, s2);
       }
       s += foo;
     }
@@ -792,6 +933,14 @@ int test_QR_update(void)
   int f;
   int s = 0;
 
+  f = test_QR_update_dim(m35, 2 * 512.0 * GSL_DBL_EPSILON);
+  gsl_test(f, "  QR_update m(3,5)");
+  s += f;
+
+  f = test_QR_update_dim(m53, 2 * 512.0 * GSL_DBL_EPSILON);
+  gsl_test(f, "  QR_update m(5,3)");
+  s += f;
+
   f = test_QR_update_dim(hilb2,  2 * 512.0 * GSL_DBL_EPSILON);
   gsl_test(f, "  QR_update hilbert(2)");
   s += f;
@@ -828,7 +977,7 @@ int test_QR_update(void)
 }
 
 
-static int
+int
 test_SV_solve_dim(const gsl_matrix * m, const double * actual, double eps)
 {
   int s = 0;
@@ -900,7 +1049,7 @@ int test_SV_solve(void)
 }
 
 
-static int
+int
 test_SV_decomp_dim(const gsl_matrix * m, double eps)
 {
   int s = 0;
@@ -929,7 +1078,8 @@ test_SV_decomp_dim(const gsl_matrix * m, double eps)
         }
     }
             
-  gsl_linalg_matmult (v, dqt, a);
+  /* compute a = v dqt */
+  gsl_blas_dgemm (CblasNoTrans, CblasNoTrans, 1.0, v, dqt, 0.0, a);
 
   for(i=0; i<M; i++) {
     for(j=0; j<N; j++) {
@@ -1006,7 +1156,7 @@ int test_SV_decomp(void)
 }
 
 
-static int
+int
 test_cholesky_solve_dim(const gsl_matrix * m, const double * actual, double eps)
 {
   int s = 0;
@@ -1058,7 +1208,7 @@ int test_cholesky_solve(void)
 }
 
 
-static int
+int
 test_cholesky_decomp_dim(const gsl_matrix * m, double eps)
 {
   int s = 0;
@@ -1085,7 +1235,8 @@ test_cholesky_decomp_dim(const gsl_matrix * m, double eps)
         }
     }
             
-  gsl_linalg_matmult (l, lt, a);
+  /* compute a = l lt */
+  gsl_blas_dgemm (CblasNoTrans, CblasNoTrans, 1.0, l, lt, 0.0, a);
 
   for(i=0; i<M; i++) {
     for(j=0; j<N; j++) {
@@ -1132,7 +1283,7 @@ int test_cholesky_decomp(void)
 }
 
 
-static int
+int
 test_HH_solve_dim(const gsl_matrix * m, const double * actual, double eps)
 {
   int s = 0;
@@ -1201,7 +1352,7 @@ int test_HH_solve(void)
 }
 
 
-static int
+int
 test_TD_solve_dim(size_t dim, double d, double od, const double * actual, double eps)
 {
   int s = 0;
@@ -1275,7 +1426,7 @@ int test_TD_solve(void)
 
 
 
-int main()
+int main(void)
 {
   gsl_ieee_env_setup ();
 
@@ -1294,11 +1445,15 @@ int main()
 
   moler10 = create_moler_matrix(10);
 
-  gsl_test(test_matmult(),        "Matrix Multiply");
-  gsl_test(test_matmult_mod(),    "Matrix Multiply with Modification");
+  /* Matmult now obsolete */
+#ifdef MATMULT
+  gsl_test(test_matmult(),        "Matrix Multiply"); 
+  gsl_test(test_matmult_mod(),    "Matrix Multiply with Modification"); 
+#endif
   gsl_test(test_LU_solve(),       "LU Decomposition and Solve");
   gsl_test(test_QR_decomp(),      "QR Decomposition");
   gsl_test(test_QR_solve(),       "QR Solve");
+  gsl_test(test_QR_lssolve(),     "QR LS Solve");
   gsl_test(test_QR_update(),      "QR Rank-1 Update");
   gsl_test(test_QRPT_decomp(),    "QRPT Decomposition");
   gsl_test(test_QRPT_solve(),     "QRPT Solve");
