@@ -36,9 +36,7 @@
 
 __BEGIN_DECLS
 
-typedef struct gsl_matrix_char_struct gsl_matrix_char;
-
-struct gsl_matrix_char_struct
+typedef struct 
 {
   size_t size1;
   size_t size2;
@@ -46,7 +44,9 @@ struct gsl_matrix_char_struct
   char * data;
   gsl_block_char * block;
   int owner;
-} ;
+} gsl_matrix_char;
+
+/* typedef struct gsl_matrix_char_struct gsl_matrix_char;*/
 
 gsl_matrix_char * 
 gsl_matrix_char_alloc (const size_t n1, const size_t n2);
@@ -78,10 +78,32 @@ gsl_vector_char_alloc_col_from_matrix (gsl_matrix_char * m,
 
 void gsl_matrix_char_free (gsl_matrix_char * m);
 
+int gsl_matrix_char_view_from_matrix (gsl_matrix_char * m, 
+                                       gsl_matrix_char * mm,
+                                       const size_t k1,
+                                       const size_t k2,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+int gsl_matrix_char_view_from_vector (gsl_matrix_char * m, 
+                                       gsl_vector_char * v,
+                                       const size_t offset,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+
+int gsl_matrix_char_view_from_array (gsl_matrix_char * m, 
+                                      char * base,
+                                      const size_t offset,
+                                      const size_t n1, 
+                                      const size_t n2);
+
 gsl_matrix_char gsl_matrix_char_view (char * m, 
                                         const size_t n1, 
                                         const size_t n2);
 
+int gsl_vector_char_view_row_from_matrix (gsl_vector_char * v, gsl_matrix_char * m, const size_t i);
+int gsl_vector_char_view_col_from_matrix (gsl_vector_char * v, gsl_matrix_char * m, const size_t j);
 
 void gsl_matrix_char_set_zero (gsl_matrix_char * m);
 void gsl_matrix_char_set_identity (gsl_matrix_char * m);
@@ -89,7 +111,7 @@ void gsl_matrix_char_set_all (gsl_matrix_char * m, char x);
 
 char * gsl_matrix_char_ptr(const gsl_matrix_char * m, const size_t i, const size_t j);
 char   gsl_matrix_char_get(const gsl_matrix_char * m, const size_t i, const size_t j);
-void    gsl_matrix_char_set(gsl_matrix_char * m, const size_t i, const size_t j, char x);
+void    gsl_matrix_char_set(gsl_matrix_char * m, const size_t i, const size_t j, const char x);
 
 int gsl_matrix_char_fread (FILE * stream, gsl_matrix_char * m) ;
 int gsl_matrix_char_fwrite (FILE * stream, const gsl_matrix_char * m) ;
@@ -106,14 +128,14 @@ int gsl_matrix_char_transpose (gsl_matrix_char * m);
 int gsl_matrix_char_transpose_memcpy (gsl_matrix_char * dest, const gsl_matrix_char * src);
 
 
-gsl_matrix_char gsl_matrix_char_view (char * m, size_t n1, size_t n2);
-gsl_matrix_char gsl_matrix_char_submatrix (gsl_matrix_char * m, size_t i, size_t j, size_t n1, size_t n2);
-gsl_vector_char gsl_matrix_char_row (gsl_matrix_char * m, size_t i);
-gsl_vector_char gsl_matrix_char_column (gsl_matrix_char * m, size_t j);
+gsl_matrix_char gsl_matrix_char_submatrix (gsl_matrix_char * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+gsl_vector_char gsl_matrix_char_row (gsl_matrix_char * m, const size_t i);
+gsl_vector_char gsl_matrix_char_column (gsl_matrix_char * m, const size_t j);
 gsl_vector_char gsl_matrix_char_diagonal (gsl_matrix_char * m);
 
-const gsl_vector_char gsl_matrix_char_const_row (const gsl_matrix_char * m, size_t i);
-const gsl_vector_char gsl_matrix_char_const_column (const gsl_matrix_char * m, size_t j);
+const gsl_matrix_char gsl_matrix_char_const_submatrix (const gsl_matrix_char * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+const gsl_vector_char gsl_matrix_char_const_row (const gsl_matrix_char * m, const size_t i);
+const gsl_vector_char gsl_matrix_char_const_column (const gsl_matrix_char * m, const size_t j);
 const gsl_vector_char gsl_matrix_char_const_diagonal (const gsl_matrix_char * m);
 
 char gsl_matrix_char_max (const gsl_matrix_char * m);
@@ -141,13 +163,6 @@ int gsl_matrix_char_get_col(gsl_vector_char * v, const gsl_matrix_char * m, cons
 int gsl_matrix_char_set_row(gsl_matrix_char * m, const size_t i, const gsl_vector_char * v);
 int gsl_matrix_char_set_col(gsl_matrix_char * m, const size_t j, const gsl_vector_char * v);
 
-int gsl_vector_char_view_row_from_matrix (gsl_vector_char * v, gsl_matrix_char * m, const size_t i);
-int gsl_vector_char_view_col_from_matrix (gsl_vector_char * v, gsl_matrix_char * m, const size_t j);
-
-int gsl_matrix_char_view_from_vector (gsl_matrix_char * m, gsl_vector_char * base, const size_t offset, const size_t n1, const size_t n2, const size_t d2);
-
-
-
 extern int gsl_check_range ;
 
 /* inline functions if you are using GCC */
