@@ -37,9 +37,7 @@
 
 __BEGIN_DECLS
 
-typedef struct gsl_matrix_complex_float_struct gsl_matrix_complex_float;
-
-struct gsl_matrix_complex_float_struct 
+typedef struct 
 {
   size_t size1;
   size_t size2;
@@ -47,8 +45,9 @@ struct gsl_matrix_complex_float_struct
   float * data;
   gsl_block_complex_float * block;
   int owner;
-} ;
+} gsl_matrix_complex_float ;
 
+/* typedef struct gsl_matrix_complex_float_struct gsl_matrix_complex_float; */
 
 gsl_matrix_complex_float * 
 gsl_matrix_complex_float_alloc (const size_t n1, const size_t n2);
@@ -77,10 +76,34 @@ gsl_vector_complex_float_alloc_col_from_matrix (gsl_matrix_complex_float * m,
 
 void gsl_matrix_complex_float_free (gsl_matrix_complex_float * m);
 
+
+int gsl_matrix_complex_float_view_from_matrix (gsl_matrix_complex_float * m, 
+                                       gsl_matrix_complex_float * mm,
+                                       const size_t k1,
+                                       const size_t k2,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+int gsl_matrix_complex_float_view_from_vector (gsl_matrix_complex_float * m, 
+                                       gsl_vector_complex_float * v,
+                                       const size_t offset,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+
+int gsl_matrix_complex_float_view_from_array (gsl_matrix_complex_float * m, 
+                                      float * base,
+                                      const size_t offset,
+                                      const size_t n1, 
+                                      const size_t n2);
+
 gsl_matrix_complex_float gsl_matrix_complex_float_view (float * m, 
                                                         const size_t n1, 
                                                         const size_t n2);
 
+int gsl_vector_complex_float_view_row_from_matrix (gsl_vector_complex_float * v, gsl_matrix_complex_float * m, const size_t i);
+int gsl_vector_complex_float_view_col_from_matrix (gsl_vector_complex_float * v, gsl_matrix_complex_float * m, const size_t j);
+
 void gsl_matrix_complex_float_set_zero (gsl_matrix_complex_float * m);
 void gsl_matrix_complex_float_set_identity (gsl_matrix_complex_float * m);
 void gsl_matrix_complex_float_set_all (gsl_matrix_complex_float * m, gsl_complex_float x);
@@ -104,11 +127,16 @@ int gsl_matrix_complex_float_swap_rowcol(gsl_matrix_complex_float * m, const siz
 int gsl_matrix_complex_float_transpose (gsl_matrix_complex_float * m);
 int gsl_matrix_complex_float_transpose_memcpy (gsl_matrix_complex_float * dest, const gsl_matrix_complex_float * src);
 
-gsl_matrix_complex_float gsl_matrix_complex_float_submatrix (gsl_matrix_complex_float * m, size_t i, size_t j, size_t n1, size_t n2);
-gsl_vector_complex_float gsl_matrix_complex_float_row (gsl_matrix_complex_float * m, size_t i);
-gsl_vector_complex_float gsl_matrix_complex_float_column (gsl_matrix_complex_float * m, size_t j);
+gsl_matrix_complex_float gsl_matrix_complex_float_submatrix (gsl_matrix_complex_float * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+gsl_vector_complex_float gsl_matrix_complex_float_row (gsl_matrix_complex_float * m, const size_t i);
+gsl_vector_complex_float gsl_matrix_complex_float_column (gsl_matrix_complex_float * m, const size_t j);
 gsl_vector_complex_float gsl_matrix_complex_float_diagonal (gsl_matrix_complex_float * m);
 
+const gsl_matrix_complex_float gsl_matrix_complex_float_const_submatrix (const gsl_matrix_complex_float * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+const gsl_vector_complex_float gsl_matrix_complex_float_const_row (const gsl_matrix_complex_float * m, const size_t i);
+const gsl_vector_complex_float gsl_matrix_complex_float_const_column (const gsl_matrix_complex_float * m, const size_t j);
+const gsl_vector_complex_float gsl_matrix_complex_float_const_diagonal (const gsl_matrix_complex_float * m);
+
 int gsl_matrix_complex_float_isnull (const gsl_matrix_complex_float * m);
 
 /***********************************************************************/
@@ -119,11 +147,6 @@ int gsl_matrix_complex_float_get_col(gsl_vector_complex_float * v, const gsl_mat
 int gsl_matrix_complex_float_set_row(gsl_matrix_complex_float * m, const size_t i, const gsl_vector_complex_float * v);
 int gsl_matrix_complex_float_set_col(gsl_matrix_complex_float * m, const size_t j, const gsl_vector_complex_float * v);
 
-int gsl_vector_complex_float_view_row_from_matrix (gsl_vector_complex_float * v, gsl_matrix_complex_float * m, const size_t i);
-int gsl_vector_complex_float_view_col_from_matrix (gsl_vector_complex_float * v, gsl_matrix_complex_float * m, const size_t j);
-
-int gsl_matrix_complex_float_view_from_vector (gsl_matrix_complex_float * m, gsl_vector_complex_float * base, const size_t offset, const size_t n1, const size_t n2, const size_t d2);
-
 extern int gsl_check_range ;
 
 #ifdef HAVE_INLINE
