@@ -36,9 +36,7 @@
 
 __BEGIN_DECLS
 
-typedef struct gsl_matrix_struct gsl_matrix;
-
-struct gsl_matrix_struct
+typedef struct 
 {
   size_t size1;
   size_t size2;
@@ -46,7 +44,9 @@ struct gsl_matrix_struct
   double * data;
   gsl_block * block;
   int owner;
-} ;
+} gsl_matrix;
+
+/* typedef struct gsl_matrix_struct gsl_matrix;*/
 
 gsl_matrix * 
 gsl_matrix_alloc (const size_t n1, const size_t n2);
@@ -78,10 +78,32 @@ gsl_vector_alloc_col_from_matrix (gsl_matrix * m,
 
 void gsl_matrix_free (gsl_matrix * m);
 
+int gsl_matrix_view_from_matrix (gsl_matrix * m, 
+                                       gsl_matrix * mm,
+                                       const size_t k1,
+                                       const size_t k2,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+int gsl_matrix_view_from_vector (gsl_matrix * m, 
+                                       gsl_vector * v,
+                                       const size_t offset,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+
+int gsl_matrix_view_from_array (gsl_matrix * m, 
+                                      double * base,
+                                      const size_t offset,
+                                      const size_t n1, 
+                                      const size_t n2);
+
 gsl_matrix gsl_matrix_view (double * m, 
                                         const size_t n1, 
                                         const size_t n2);
 
+int gsl_vector_view_row_from_matrix (gsl_vector * v, gsl_matrix * m, const size_t i);
+int gsl_vector_view_col_from_matrix (gsl_vector * v, gsl_matrix * m, const size_t j);
 
 void gsl_matrix_set_zero (gsl_matrix * m);
 void gsl_matrix_set_identity (gsl_matrix * m);
@@ -89,7 +111,7 @@ void gsl_matrix_set_all (gsl_matrix * m, double x);
 
 double * gsl_matrix_ptr(const gsl_matrix * m, const size_t i, const size_t j);
 double   gsl_matrix_get(const gsl_matrix * m, const size_t i, const size_t j);
-void    gsl_matrix_set(gsl_matrix * m, const size_t i, const size_t j, double x);
+void    gsl_matrix_set(gsl_matrix * m, const size_t i, const size_t j, const double x);
 
 int gsl_matrix_fread (FILE * stream, gsl_matrix * m) ;
 int gsl_matrix_fwrite (FILE * stream, const gsl_matrix * m) ;
@@ -106,14 +128,14 @@ int gsl_matrix_transpose (gsl_matrix * m);
 int gsl_matrix_transpose_memcpy (gsl_matrix * dest, const gsl_matrix * src);
 
 
-gsl_matrix gsl_matrix_view (double * m, size_t n1, size_t n2);
-gsl_matrix gsl_matrix_submatrix (gsl_matrix * m, size_t i, size_t j, size_t n1, size_t n2);
-gsl_vector gsl_matrix_row (gsl_matrix * m, size_t i);
-gsl_vector gsl_matrix_column (gsl_matrix * m, size_t j);
+gsl_matrix gsl_matrix_submatrix (gsl_matrix * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+gsl_vector gsl_matrix_row (gsl_matrix * m, const size_t i);
+gsl_vector gsl_matrix_column (gsl_matrix * m, const size_t j);
 gsl_vector gsl_matrix_diagonal (gsl_matrix * m);
 
-const gsl_vector gsl_matrix_const_row (const gsl_matrix * m, size_t i);
-const gsl_vector gsl_matrix_const_column (const gsl_matrix * m, size_t j);
+const gsl_matrix gsl_matrix_const_submatrix (const gsl_matrix * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+const gsl_vector gsl_matrix_const_row (const gsl_matrix * m, const size_t i);
+const gsl_vector gsl_matrix_const_column (const gsl_matrix * m, const size_t j);
 const gsl_vector gsl_matrix_const_diagonal (const gsl_matrix * m);
 
 double gsl_matrix_max (const gsl_matrix * m);
@@ -141,13 +163,6 @@ int gsl_matrix_get_col(gsl_vector * v, const gsl_matrix * m, const size_t j);
 int gsl_matrix_set_row(gsl_matrix * m, const size_t i, const gsl_vector * v);
 int gsl_matrix_set_col(gsl_matrix * m, const size_t j, const gsl_vector * v);
 
-int gsl_vector_view_row_from_matrix (gsl_vector * v, gsl_matrix * m, const size_t i);
-int gsl_vector_view_col_from_matrix (gsl_vector * v, gsl_matrix * m, const size_t j);
-
-int gsl_matrix_view_from_vector (gsl_matrix * m, gsl_vector * base, const size_t offset, const size_t n1, const size_t n2, const size_t d2);
-
-
-
 extern int gsl_check_range ;
 
 /* inline functions if you are using GCC */
