@@ -36,9 +36,7 @@
 
 __BEGIN_DECLS
 
-typedef struct gsl_matrix_int_struct gsl_matrix_int;
-
-struct gsl_matrix_int_struct
+typedef struct 
 {
   size_t size1;
   size_t size2;
@@ -46,7 +44,9 @@ struct gsl_matrix_int_struct
   int * data;
   gsl_block_int * block;
   int owner;
-} ;
+} gsl_matrix_int;
+
+/* typedef struct gsl_matrix_int_struct gsl_matrix_int;*/
 
 gsl_matrix_int * 
 gsl_matrix_int_alloc (const size_t n1, const size_t n2);
@@ -78,10 +78,32 @@ gsl_vector_int_alloc_col_from_matrix (gsl_matrix_int * m,
 
 void gsl_matrix_int_free (gsl_matrix_int * m);
 
+int gsl_matrix_int_view_from_matrix (gsl_matrix_int * m, 
+                                       gsl_matrix_int * mm,
+                                       const size_t k1,
+                                       const size_t k2,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+int gsl_matrix_int_view_from_vector (gsl_matrix_int * m, 
+                                       gsl_vector_int * v,
+                                       const size_t offset,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+
+int gsl_matrix_int_view_from_array (gsl_matrix_int * m, 
+                                      int * base,
+                                      const size_t offset,
+                                      const size_t n1, 
+                                      const size_t n2);
+
 gsl_matrix_int gsl_matrix_int_view (int * m, 
                                         const size_t n1, 
                                         const size_t n2);
 
+int gsl_vector_int_view_row_from_matrix (gsl_vector_int * v, gsl_matrix_int * m, const size_t i);
+int gsl_vector_int_view_col_from_matrix (gsl_vector_int * v, gsl_matrix_int * m, const size_t j);
 
 void gsl_matrix_int_set_zero (gsl_matrix_int * m);
 void gsl_matrix_int_set_identity (gsl_matrix_int * m);
@@ -89,7 +111,7 @@ void gsl_matrix_int_set_all (gsl_matrix_int * m, int x);
 
 int * gsl_matrix_int_ptr(const gsl_matrix_int * m, const size_t i, const size_t j);
 int   gsl_matrix_int_get(const gsl_matrix_int * m, const size_t i, const size_t j);
-void    gsl_matrix_int_set(gsl_matrix_int * m, const size_t i, const size_t j, int x);
+void    gsl_matrix_int_set(gsl_matrix_int * m, const size_t i, const size_t j, const int x);
 
 int gsl_matrix_int_fread (FILE * stream, gsl_matrix_int * m) ;
 int gsl_matrix_int_fwrite (FILE * stream, const gsl_matrix_int * m) ;
@@ -106,14 +128,14 @@ int gsl_matrix_int_transpose (gsl_matrix_int * m);
 int gsl_matrix_int_transpose_memcpy (gsl_matrix_int * dest, const gsl_matrix_int * src);
 
 
-gsl_matrix_int gsl_matrix_int_view (int * m, size_t n1, size_t n2);
-gsl_matrix_int gsl_matrix_int_submatrix (gsl_matrix_int * m, size_t i, size_t j, size_t n1, size_t n2);
-gsl_vector_int gsl_matrix_int_row (gsl_matrix_int * m, size_t i);
-gsl_vector_int gsl_matrix_int_column (gsl_matrix_int * m, size_t j);
+gsl_matrix_int gsl_matrix_int_submatrix (gsl_matrix_int * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+gsl_vector_int gsl_matrix_int_row (gsl_matrix_int * m, const size_t i);
+gsl_vector_int gsl_matrix_int_column (gsl_matrix_int * m, const size_t j);
 gsl_vector_int gsl_matrix_int_diagonal (gsl_matrix_int * m);
 
-const gsl_vector_int gsl_matrix_int_const_row (const gsl_matrix_int * m, size_t i);
-const gsl_vector_int gsl_matrix_int_const_column (const gsl_matrix_int * m, size_t j);
+const gsl_matrix_int gsl_matrix_int_const_submatrix (const gsl_matrix_int * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+const gsl_vector_int gsl_matrix_int_const_row (const gsl_matrix_int * m, const size_t i);
+const gsl_vector_int gsl_matrix_int_const_column (const gsl_matrix_int * m, const size_t j);
 const gsl_vector_int gsl_matrix_int_const_diagonal (const gsl_matrix_int * m);
 
 int gsl_matrix_int_max (const gsl_matrix_int * m);
@@ -141,13 +163,6 @@ int gsl_matrix_int_get_col(gsl_vector_int * v, const gsl_matrix_int * m, const s
 int gsl_matrix_int_set_row(gsl_matrix_int * m, const size_t i, const gsl_vector_int * v);
 int gsl_matrix_int_set_col(gsl_matrix_int * m, const size_t j, const gsl_vector_int * v);
 
-int gsl_vector_int_view_row_from_matrix (gsl_vector_int * v, gsl_matrix_int * m, const size_t i);
-int gsl_vector_int_view_col_from_matrix (gsl_vector_int * v, gsl_matrix_int * m, const size_t j);
-
-int gsl_matrix_int_view_from_vector (gsl_matrix_int * m, gsl_vector_int * base, const size_t offset, const size_t n1, const size_t n2, const size_t d2);
-
-
-
 extern int gsl_check_range ;
 
 /* inline functions if you are using GCC */
