@@ -36,9 +36,7 @@
 
 __BEGIN_DECLS
 
-typedef struct gsl_matrix_long_double_struct gsl_matrix_long_double;
-
-struct gsl_matrix_long_double_struct
+typedef struct 
 {
   size_t size1;
   size_t size2;
@@ -46,7 +44,9 @@ struct gsl_matrix_long_double_struct
   long double * data;
   gsl_block_long_double * block;
   int owner;
-} ;
+} gsl_matrix_long_double;
+
+/* typedef struct gsl_matrix_long_double_struct gsl_matrix_long_double;*/
 
 gsl_matrix_long_double * 
 gsl_matrix_long_double_alloc (const size_t n1, const size_t n2);
@@ -78,10 +78,32 @@ gsl_vector_long_double_alloc_col_from_matrix (gsl_matrix_long_double * m,
 
 void gsl_matrix_long_double_free (gsl_matrix_long_double * m);
 
+int gsl_matrix_long_double_view_from_matrix (gsl_matrix_long_double * m, 
+                                       gsl_matrix_long_double * mm,
+                                       const size_t k1,
+                                       const size_t k2,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+int gsl_matrix_long_double_view_from_vector (gsl_matrix_long_double * m, 
+                                       gsl_vector_long_double * v,
+                                       const size_t offset,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+
+int gsl_matrix_long_double_view_from_array (gsl_matrix_long_double * m, 
+                                      long double * base,
+                                      const size_t offset,
+                                      const size_t n1, 
+                                      const size_t n2);
+
 gsl_matrix_long_double gsl_matrix_long_double_view (long double * m, 
                                         const size_t n1, 
                                         const size_t n2);
 
+int gsl_vector_long_double_view_row_from_matrix (gsl_vector_long_double * v, gsl_matrix_long_double * m, const size_t i);
+int gsl_vector_long_double_view_col_from_matrix (gsl_vector_long_double * v, gsl_matrix_long_double * m, const size_t j);
 
 void gsl_matrix_long_double_set_zero (gsl_matrix_long_double * m);
 void gsl_matrix_long_double_set_identity (gsl_matrix_long_double * m);
@@ -89,7 +111,7 @@ void gsl_matrix_long_double_set_all (gsl_matrix_long_double * m, long double x);
 
 long double * gsl_matrix_long_double_ptr(const gsl_matrix_long_double * m, const size_t i, const size_t j);
 long double   gsl_matrix_long_double_get(const gsl_matrix_long_double * m, const size_t i, const size_t j);
-void    gsl_matrix_long_double_set(gsl_matrix_long_double * m, const size_t i, const size_t j, long double x);
+void    gsl_matrix_long_double_set(gsl_matrix_long_double * m, const size_t i, const size_t j, const long double x);
 
 int gsl_matrix_long_double_fread (FILE * stream, gsl_matrix_long_double * m) ;
 int gsl_matrix_long_double_fwrite (FILE * stream, const gsl_matrix_long_double * m) ;
@@ -106,14 +128,14 @@ int gsl_matrix_long_double_transpose (gsl_matrix_long_double * m);
 int gsl_matrix_long_double_transpose_memcpy (gsl_matrix_long_double * dest, const gsl_matrix_long_double * src);
 
 
-gsl_matrix_long_double gsl_matrix_long_double_view (long double * m, size_t n1, size_t n2);
-gsl_matrix_long_double gsl_matrix_long_double_submatrix (gsl_matrix_long_double * m, size_t i, size_t j, size_t n1, size_t n2);
-gsl_vector_long_double gsl_matrix_long_double_row (gsl_matrix_long_double * m, size_t i);
-gsl_vector_long_double gsl_matrix_long_double_column (gsl_matrix_long_double * m, size_t j);
+gsl_matrix_long_double gsl_matrix_long_double_submatrix (gsl_matrix_long_double * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+gsl_vector_long_double gsl_matrix_long_double_row (gsl_matrix_long_double * m, const size_t i);
+gsl_vector_long_double gsl_matrix_long_double_column (gsl_matrix_long_double * m, const size_t j);
 gsl_vector_long_double gsl_matrix_long_double_diagonal (gsl_matrix_long_double * m);
 
-const gsl_vector_long_double gsl_matrix_long_double_const_row (const gsl_matrix_long_double * m, size_t i);
-const gsl_vector_long_double gsl_matrix_long_double_const_column (const gsl_matrix_long_double * m, size_t j);
+const gsl_matrix_long_double gsl_matrix_long_double_const_submatrix (const gsl_matrix_long_double * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+const gsl_vector_long_double gsl_matrix_long_double_const_row (const gsl_matrix_long_double * m, const size_t i);
+const gsl_vector_long_double gsl_matrix_long_double_const_column (const gsl_matrix_long_double * m, const size_t j);
 const gsl_vector_long_double gsl_matrix_long_double_const_diagonal (const gsl_matrix_long_double * m);
 
 long double gsl_matrix_long_double_max (const gsl_matrix_long_double * m);
@@ -141,13 +163,6 @@ int gsl_matrix_long_double_get_col(gsl_vector_long_double * v, const gsl_matrix_
 int gsl_matrix_long_double_set_row(gsl_matrix_long_double * m, const size_t i, const gsl_vector_long_double * v);
 int gsl_matrix_long_double_set_col(gsl_matrix_long_double * m, const size_t j, const gsl_vector_long_double * v);
 
-int gsl_vector_long_double_view_row_from_matrix (gsl_vector_long_double * v, gsl_matrix_long_double * m, const size_t i);
-int gsl_vector_long_double_view_col_from_matrix (gsl_vector_long_double * v, gsl_matrix_long_double * m, const size_t j);
-
-int gsl_matrix_long_double_view_from_vector (gsl_matrix_long_double * m, gsl_vector_long_double * base, const size_t offset, const size_t n1, const size_t n2, const size_t d2);
-
-
-
 extern int gsl_check_range ;
 
 /* inline functions if you are using GCC */
