@@ -36,9 +36,7 @@
 
 __BEGIN_DECLS
 
-typedef struct gsl_matrix_ulong_struct gsl_matrix_ulong;
-
-struct gsl_matrix_ulong_struct
+typedef struct 
 {
   size_t size1;
   size_t size2;
@@ -46,7 +44,9 @@ struct gsl_matrix_ulong_struct
   unsigned long * data;
   gsl_block_ulong * block;
   int owner;
-} ;
+} gsl_matrix_ulong;
+
+/* typedef struct gsl_matrix_ulong_struct gsl_matrix_ulong;*/
 
 gsl_matrix_ulong * 
 gsl_matrix_ulong_alloc (const size_t n1, const size_t n2);
@@ -78,10 +78,32 @@ gsl_vector_ulong_alloc_col_from_matrix (gsl_matrix_ulong * m,
 
 void gsl_matrix_ulong_free (gsl_matrix_ulong * m);
 
+int gsl_matrix_ulong_view_from_matrix (gsl_matrix_ulong * m, 
+                                       gsl_matrix_ulong * mm,
+                                       const size_t k1,
+                                       const size_t k2,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+int gsl_matrix_ulong_view_from_vector (gsl_matrix_ulong * m, 
+                                       gsl_vector_ulong * v,
+                                       const size_t offset,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+
+int gsl_matrix_ulong_view_from_array (gsl_matrix_ulong * m, 
+                                      unsigned long * base,
+                                      const size_t offset,
+                                      const size_t n1, 
+                                      const size_t n2);
+
 gsl_matrix_ulong gsl_matrix_ulong_view (unsigned long * m, 
                                         const size_t n1, 
                                         const size_t n2);
 
+int gsl_vector_ulong_view_row_from_matrix (gsl_vector_ulong * v, gsl_matrix_ulong * m, const size_t i);
+int gsl_vector_ulong_view_col_from_matrix (gsl_vector_ulong * v, gsl_matrix_ulong * m, const size_t j);
 
 void gsl_matrix_ulong_set_zero (gsl_matrix_ulong * m);
 void gsl_matrix_ulong_set_identity (gsl_matrix_ulong * m);
@@ -89,7 +111,7 @@ void gsl_matrix_ulong_set_all (gsl_matrix_ulong * m, unsigned long x);
 
 unsigned long * gsl_matrix_ulong_ptr(const gsl_matrix_ulong * m, const size_t i, const size_t j);
 unsigned long   gsl_matrix_ulong_get(const gsl_matrix_ulong * m, const size_t i, const size_t j);
-void    gsl_matrix_ulong_set(gsl_matrix_ulong * m, const size_t i, const size_t j, unsigned long x);
+void    gsl_matrix_ulong_set(gsl_matrix_ulong * m, const size_t i, const size_t j, const unsigned long x);
 
 int gsl_matrix_ulong_fread (FILE * stream, gsl_matrix_ulong * m) ;
 int gsl_matrix_ulong_fwrite (FILE * stream, const gsl_matrix_ulong * m) ;
@@ -106,14 +128,14 @@ int gsl_matrix_ulong_transpose (gsl_matrix_ulong * m);
 int gsl_matrix_ulong_transpose_memcpy (gsl_matrix_ulong * dest, const gsl_matrix_ulong * src);
 
 
-gsl_matrix_ulong gsl_matrix_ulong_view (unsigned long * m, size_t n1, size_t n2);
-gsl_matrix_ulong gsl_matrix_ulong_submatrix (gsl_matrix_ulong * m, size_t i, size_t j, size_t n1, size_t n2);
-gsl_vector_ulong gsl_matrix_ulong_row (gsl_matrix_ulong * m, size_t i);
-gsl_vector_ulong gsl_matrix_ulong_column (gsl_matrix_ulong * m, size_t j);
+gsl_matrix_ulong gsl_matrix_ulong_submatrix (gsl_matrix_ulong * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+gsl_vector_ulong gsl_matrix_ulong_row (gsl_matrix_ulong * m, const size_t i);
+gsl_vector_ulong gsl_matrix_ulong_column (gsl_matrix_ulong * m, const size_t j);
 gsl_vector_ulong gsl_matrix_ulong_diagonal (gsl_matrix_ulong * m);
 
-const gsl_vector_ulong gsl_matrix_ulong_const_row (const gsl_matrix_ulong * m, size_t i);
-const gsl_vector_ulong gsl_matrix_ulong_const_column (const gsl_matrix_ulong * m, size_t j);
+const gsl_matrix_ulong gsl_matrix_ulong_const_submatrix (const gsl_matrix_ulong * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+const gsl_vector_ulong gsl_matrix_ulong_const_row (const gsl_matrix_ulong * m, const size_t i);
+const gsl_vector_ulong gsl_matrix_ulong_const_column (const gsl_matrix_ulong * m, const size_t j);
 const gsl_vector_ulong gsl_matrix_ulong_const_diagonal (const gsl_matrix_ulong * m);
 
 unsigned long gsl_matrix_ulong_max (const gsl_matrix_ulong * m);
@@ -141,13 +163,6 @@ int gsl_matrix_ulong_get_col(gsl_vector_ulong * v, const gsl_matrix_ulong * m, c
 int gsl_matrix_ulong_set_row(gsl_matrix_ulong * m, const size_t i, const gsl_vector_ulong * v);
 int gsl_matrix_ulong_set_col(gsl_matrix_ulong * m, const size_t j, const gsl_vector_ulong * v);
 
-int gsl_vector_ulong_view_row_from_matrix (gsl_vector_ulong * v, gsl_matrix_ulong * m, const size_t i);
-int gsl_vector_ulong_view_col_from_matrix (gsl_vector_ulong * v, gsl_matrix_ulong * m, const size_t j);
-
-int gsl_matrix_ulong_view_from_vector (gsl_matrix_ulong * m, gsl_vector_ulong * base, const size_t offset, const size_t n1, const size_t n2, const size_t d2);
-
-
-
 extern int gsl_check_range ;
 
 /* inline functions if you are using GCC */
