@@ -36,9 +36,7 @@
 
 __BEGIN_DECLS
 
-typedef struct gsl_matrix_ushort_struct gsl_matrix_ushort;
-
-struct gsl_matrix_ushort_struct
+typedef struct 
 {
   size_t size1;
   size_t size2;
@@ -46,7 +44,9 @@ struct gsl_matrix_ushort_struct
   unsigned short * data;
   gsl_block_ushort * block;
   int owner;
-} ;
+} gsl_matrix_ushort;
+
+/* typedef struct gsl_matrix_ushort_struct gsl_matrix_ushort;*/
 
 gsl_matrix_ushort * 
 gsl_matrix_ushort_alloc (const size_t n1, const size_t n2);
@@ -78,10 +78,32 @@ gsl_vector_ushort_alloc_col_from_matrix (gsl_matrix_ushort * m,
 
 void gsl_matrix_ushort_free (gsl_matrix_ushort * m);
 
+int gsl_matrix_ushort_view_from_matrix (gsl_matrix_ushort * m, 
+                                       gsl_matrix_ushort * mm,
+                                       const size_t k1,
+                                       const size_t k2,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+int gsl_matrix_ushort_view_from_vector (gsl_matrix_ushort * m, 
+                                       gsl_vector_ushort * v,
+                                       const size_t offset,
+                                       const size_t n1, 
+                                       const size_t n2);
+
+
+int gsl_matrix_ushort_view_from_array (gsl_matrix_ushort * m, 
+                                      unsigned short * base,
+                                      const size_t offset,
+                                      const size_t n1, 
+                                      const size_t n2);
+
 gsl_matrix_ushort gsl_matrix_ushort_view (unsigned short * m, 
                                         const size_t n1, 
                                         const size_t n2);
 
+int gsl_vector_ushort_view_row_from_matrix (gsl_vector_ushort * v, gsl_matrix_ushort * m, const size_t i);
+int gsl_vector_ushort_view_col_from_matrix (gsl_vector_ushort * v, gsl_matrix_ushort * m, const size_t j);
 
 void gsl_matrix_ushort_set_zero (gsl_matrix_ushort * m);
 void gsl_matrix_ushort_set_identity (gsl_matrix_ushort * m);
@@ -89,7 +111,7 @@ void gsl_matrix_ushort_set_all (gsl_matrix_ushort * m, unsigned short x);
 
 unsigned short * gsl_matrix_ushort_ptr(const gsl_matrix_ushort * m, const size_t i, const size_t j);
 unsigned short   gsl_matrix_ushort_get(const gsl_matrix_ushort * m, const size_t i, const size_t j);
-void    gsl_matrix_ushort_set(gsl_matrix_ushort * m, const size_t i, const size_t j, unsigned short x);
+void    gsl_matrix_ushort_set(gsl_matrix_ushort * m, const size_t i, const size_t j, const unsigned short x);
 
 int gsl_matrix_ushort_fread (FILE * stream, gsl_matrix_ushort * m) ;
 int gsl_matrix_ushort_fwrite (FILE * stream, const gsl_matrix_ushort * m) ;
@@ -106,14 +128,14 @@ int gsl_matrix_ushort_transpose (gsl_matrix_ushort * m);
 int gsl_matrix_ushort_transpose_memcpy (gsl_matrix_ushort * dest, const gsl_matrix_ushort * src);
 
 
-gsl_matrix_ushort gsl_matrix_ushort_view (unsigned short * m, size_t n1, size_t n2);
-gsl_matrix_ushort gsl_matrix_ushort_submatrix (gsl_matrix_ushort * m, size_t i, size_t j, size_t n1, size_t n2);
-gsl_vector_ushort gsl_matrix_ushort_row (gsl_matrix_ushort * m, size_t i);
-gsl_vector_ushort gsl_matrix_ushort_column (gsl_matrix_ushort * m, size_t j);
+gsl_matrix_ushort gsl_matrix_ushort_submatrix (gsl_matrix_ushort * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+gsl_vector_ushort gsl_matrix_ushort_row (gsl_matrix_ushort * m, const size_t i);
+gsl_vector_ushort gsl_matrix_ushort_column (gsl_matrix_ushort * m, const size_t j);
 gsl_vector_ushort gsl_matrix_ushort_diagonal (gsl_matrix_ushort * m);
 
-const gsl_vector_ushort gsl_matrix_ushort_const_row (const gsl_matrix_ushort * m, size_t i);
-const gsl_vector_ushort gsl_matrix_ushort_const_column (const gsl_matrix_ushort * m, size_t j);
+const gsl_matrix_ushort gsl_matrix_ushort_const_submatrix (const gsl_matrix_ushort * m, const size_t i, const size_t j, const size_t n1, const size_t n2);
+const gsl_vector_ushort gsl_matrix_ushort_const_row (const gsl_matrix_ushort * m, const size_t i);
+const gsl_vector_ushort gsl_matrix_ushort_const_column (const gsl_matrix_ushort * m, const size_t j);
 const gsl_vector_ushort gsl_matrix_ushort_const_diagonal (const gsl_matrix_ushort * m);
 
 unsigned short gsl_matrix_ushort_max (const gsl_matrix_ushort * m);
@@ -141,13 +163,6 @@ int gsl_matrix_ushort_get_col(gsl_vector_ushort * v, const gsl_matrix_ushort * m
 int gsl_matrix_ushort_set_row(gsl_matrix_ushort * m, const size_t i, const gsl_vector_ushort * v);
 int gsl_matrix_ushort_set_col(gsl_matrix_ushort * m, const size_t j, const gsl_vector_ushort * v);
 
-int gsl_vector_ushort_view_row_from_matrix (gsl_vector_ushort * v, gsl_matrix_ushort * m, const size_t i);
-int gsl_vector_ushort_view_col_from_matrix (gsl_vector_ushort * v, gsl_matrix_ushort * m, const size_t j);
-
-int gsl_matrix_ushort_view_from_vector (gsl_matrix_ushort * m, gsl_vector_ushort * base, const size_t offset, const size_t n1, const size_t n2, const size_t d2);
-
-
-
 extern int gsl_check_range ;
 
 /* inline functions if you are using GCC */
