@@ -19,7 +19,7 @@
 
 /* Some things common to all the Monte-Carlo implementations */
 /* Author: MJB */
-/* RCS: $Id: gsl_monte.h,v 1.4 2000/05/04 11:25:04 bjg Exp $ */
+/* RCS: $Id: gsl_monte.h,v 1.5 2000/11/16 19:55:30 bjg Exp $ */
 
 #ifndef __GSL_MONTE_H__
 #define __GSL_MONTE_H__
@@ -40,7 +40,15 @@ __BEGIN_DECLS
    integration functions, and make it easy to change things.
 */
 
-typedef double (*gsl_monte_f_T)(double *);
+struct gsl_monte_function_struct {
+  double (*f)(double * x_array, size_t dim, void * params);
+  size_t dim;
+  void * params;
+};
+
+typedef struct gsl_monte_function_struct gsl_monte_function;
+
+#define GSL_MONTE_FN_EVAL(F,x) (*((F)->f))(x,(F)->dim,(F)->params)
 
 
 __END_DECLS
