@@ -20,6 +20,7 @@
 /* directional_minimize.c -- wrapper for calling the one dimensional
    minimization algorithm for vector functions */
 
+#include <config.h>
 #include <gsl/gsl_multimin.h>
 #include <gsl/gsl_blas_types.h>
 #include <gsl/gsl_blas.h>
@@ -59,7 +60,7 @@ double gsl_multimin_to_single_eval(double x, void * oparams)
 
 gsl_multimin_to_single *
 gsl_multimin_to_single_alloc(const gsl_multimin_function *f,
-			     gsl_vector * starting_point,
+			     const gsl_vector * starting_point,
 			     gsl_vector * direction) {
   gsl_multimin_to_single *wrapper;
   const size_t n = f->n ;
@@ -99,7 +100,7 @@ gsl_multimin_to_single_alloc(const gsl_multimin_function *f,
 int
 gsl_multimin_to_single_set(gsl_multimin_to_single *w,
 			   const gsl_multimin_function *f,
-			   gsl_vector * starting_point,
+			   const gsl_vector * starting_point,
 			   gsl_vector * direction) {
   if (w->evaluation_point->size != starting_point->size 
       || w->evaluation_point->size != direction->size) {
@@ -146,7 +147,7 @@ gsl_multimin_to_single_function_free(gsl_function *f)
 
 gsl_multimin_to_single *
 gsl_multimin_to_single_alloc_fdf(const gsl_multimin_function_fdf *fdf,
-				 gsl_vector * starting_point,
+				 const gsl_vector * starting_point,
 				 gsl_vector * direction) {
   gsl_multimin_function f;
 
@@ -160,7 +161,7 @@ gsl_multimin_to_single_alloc_fdf(const gsl_multimin_function_fdf *fdf,
 int
 gsl_multimin_to_single_set_fdf(gsl_multimin_to_single *w,
 			       const gsl_multimin_function_fdf *fdf,
-			       gsl_vector * starting_point,
+			       const gsl_vector * starting_point,
 			       gsl_vector * direction) {
   gsl_multimin_function f;
 
