@@ -17,6 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <config.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_multimin.h>
 
@@ -93,7 +94,7 @@ gsl_multimin_fdf_history_set(gsl_multimin_fdf_history *h,
 {
   gsl_vector_memcpy(h->x,x);
   GSL_MULTIMIN_FN_EVAL_F_DF(fdf,h->x,&(h->f),h->g);
-  if (!GSL_IS_REAL(h->f))
+  if (!finite(h->f))
     GSL_ERROR("function not continuous", GSL_EBADFUNC);
   return GSL_SUCCESS;
 }
@@ -121,7 +122,7 @@ gsl_multimin_fdf_history_step(gsl_multimin_fdf_history *h,
   h->f1 = h->f;
   gsl_multimin_compute_evaluation_point(h->x,h->x1,step,direction);
   GSL_MULTIMIN_FN_EVAL_F_DF(fdf,h->x,&(h->f),h->g);
-  if (!GSL_IS_REAL(h->f))
+  if (!finite(h->f))
     GSL_ERROR("function not continuous", GSL_EBADFUNC);
   return GSL_SUCCESS;
 }
@@ -252,9 +253,7 @@ gsl_multimin_fdf_minimizer_alloc(const gsl_multimin_fdf_minimizer_type *T,
   /* Warning, we try to bypass checks */
   dummy.lower = 0;
   dummy.upper = 1;
-  s->line_search = 
-    gsl_min_fminimizer_alloc_with_values(T_line,s->f_directional,0.5,
-					 0.0,dummy,1.0,1.0);
+  s->line_search = gsl_min_fminimizer_alloc(T_line);
   
   if (s->line_search == 0)
     {
@@ -267,7 +266,10 @@ gsl_multimin_fdf_minimizer_alloc(const gsl_multimin_fdf_minimizer_type *T,
       GSL_ERROR_VAL ("failed to allocate one dimensional minimization algorithm",
 			GSL_ENOMEM, 0);     
     }
-  
+
+  gsl_min_fminimizer_set_with_values (s->line_search, 
+                                      s->f_directional, 
+                                      0.5, 0.0, dummy, 1.0, 1.0);
 
   return s;
 }
@@ -283,8 +285,10 @@ gsl_multimin_fdf_minimizer_free(gsl_multimin_fdf_minimizer *s)
   free(s);
 }
 
-gsl_vector *
-gsl_multimin_fdf_minimizer_direction_internal(gsl_multimin_fdf_minimizer *s)
+static gsl_vector * direction_internal(gsl_multimin_fdf_minimizer *s);
+
+static gsl_vector *
+direction_internal(gsl_multimin_fdf_minimizer *s)
 {
   return ((gsl_multimin_to_single *)(s->f_directional->params))->direction;
 }
@@ -292,13 +296,13 @@ gsl_multimin_fdf_minimizer_direction_internal(gsl_multimin_fdf_minimizer *s)
 const gsl_vector *
 gsl_multimin_fdf_minimizer_direction(gsl_multimin_fdf_minimizer *s)
 {
-  return gsl_multimin_fdf_minimizer_direction_internal(s);
+  return direction_internal(s);
 }
 
 int
 gsl_multimin_fdf_minimizer_next_direction(gsl_multimin_fdf_minimizer *s)
 {
-  return s->type->direction(s->state,s->history,gsl_multimin_fdf_minimizer_direction_internal(s));
+  return s->type->direction(s->state,s->history,direction_internal(s));
 }
 
 int
@@ -315,7 +319,7 @@ gsl_multimin_fdf_minimizer_bracket(gsl_multimin_fdf_minimizer *s,
   bracket.lower = 0.0;
   f_lower = s->history->f;
   f_upper = GSL_FN_EVAL(s->f_directional,first_step);
-  if (!GSL_IS_REAL(f_upper))
+  if (!finite(f_upper))
     GSL_ERROR("function not continuous", GSL_EBADFUNC);
   status =  (s->bracketing)(s->f_directional,&minimum,
 			    &f_minimum,&bracket,&f_lower,&f_upper,eval_max);
