@@ -17,6 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <config.h>
 #include <gsl/gsl_test.h>
 #include <gsl/gsl_multimin.h>
 #include <gsl/gsl_min.h>
@@ -166,5 +167,15 @@ main (void)
       T++;
     }
 
+  T = fdfminimizers;
+
+  while (*T != 0) 
+    {
+      test_fdf("NRoth", &Nroth, roth_initpt,*T,5*Nroth.n);
+      test_fdf("NWood", &Nwood, wood_initpt,*T,5*Nwood.n);
+      test_fdf("NRosenbrock", &Nrosenbrock, rosenbrock_initpt,*T,5*Nrosenbrock.n);
+      T++;
+    }
+
   return gsl_test_summary();
 }
