@@ -17,6 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <config.h>
 #include <stdio.h>
 #include <gsl/gsl_vector.h>
 #include <gsl/gsl_test.h>
@@ -134,7 +135,8 @@ test_fdf (const char * desc, gsl_multiroot_function_fdf * function,
 
   if (factor != 1.0) scale(x, factor);
 
-  s = gsl_multiroot_fdfsolver_alloc (T, function, x);
+  s = gsl_multiroot_fdfsolver_alloc (T, n);
+  gsl_multiroot_fdfsolver_set (s, function, x);
  
   do
     {
@@ -220,7 +222,8 @@ test_f (const char * desc, gsl_multiroot_function_fdf * fdf,
 
   if (factor != 1.0) scale(x, factor);
 
-  s = gsl_multiroot_fsolver_alloc (T, &function, x);
+  s = gsl_multiroot_fsolver_alloc (T, n);
+  gsl_multiroot_fsolver_set (s, &function, x);
 
 /*   printf("x "); gsl_vector_fprintf (stdout, s->x, "%g"); printf("\n"); */
 /*   printf("f "); gsl_vector_fprintf (stdout, s->f, "%g"); printf("\n"); */
