@@ -18,7 +18,7 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: bsimp.c,v 1.19 2000/06/08 19:34:15 jungman Exp $
+ * RCS:     $Id: bsimp.c,v 1.20 2001/04/23 09:38:28 bjg Exp $
  */
 /* Bader-Deuflhard implicit extrapolative stepper.
  * [Numer. Math., 41, 373 (1983)]
@@ -412,10 +412,6 @@ bsimp_step(
 
   size_t k;
 
-  if(sys->jacobian == 0) {
-    return GSL_EFAULT; /* FIXME: error condition */
-  }
-
   if(sys->dimension <= 0) {
     return GSL_EINVAL;
   }
