@@ -18,14 +18,17 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: atanint.c,v 1.11 2000/05/04 11:25:07 bjg Exp $
+ * RCS:     $Id: atanint.c,v 1.13 2001/04/24 16:13:55 bjg Exp $
  */
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_chebyshev.h"
+#include <gsl/gsl_mode.h>
 #include "gsl_sf_expint.h"
 
+#include "chebyshev.h"
+#include "cheb_eval.c"
+
 
 static double atanint_data[21] = {
   1.91040361296235937512,
@@ -50,28 +53,25 @@ static double atanint_data[21] = {
  -0.511e-17,
   0.79e-18,
 };
-static gsl_sf_cheb_series atanint_cs = {
+static cheb_series atanint_cs = {
   atanint_data,
   20,
   -1, 1,
-  (double *)0,
-  (double *)0,
   10
 };
 
 
-/*-*-*-*-*-*-*-*-*-*-*-* (semi)Private Implementations *-*-*-*-*-*-*-*-*-*-*/
+/*-*-*-*-*-*-*-*-*-*-*-* Functions with Error Codes *-*-*-*-*-*-*-*-*-*-*/
 
 int
-gsl_sf_atanint_impl(const double x, gsl_sf_result * result)
+gsl_sf_atanint_e(const double x, gsl_sf_result * result)
 {
   const double ax  = fabs(x);
   const double sgn = GSL_SIGN(x);
 
-  if(result == 0) {
-    return GSL_EFAULT;
-  }
-  else if(ax == 0.0) {
+  /* CHECK_POINTER(result) */
+
+  if(ax == 0.0) {
     result->val = 0.0;
     result->err = 0.0;
     return GSL_SUCCESS;
@@ -84,7 +84,7 @@ gsl_sf_atanint_impl(const double x, gsl_sf_result * result)
   else if(ax <= 1.0) {
     const double t = 2.0 * (x*x - 0.5);
     gsl_sf_result result_c;
-    gsl_sf_cheb_eval_impl(&atanint_cs, t, &result_c);
+    cheb_eval_e(&atanint_cs, t, &result_c);
     result->val  = x * result_c.val;
     result->err  = x * result_c.err;
     result->err += GSL_DBL_EPSILON * fabs(result->val);
@@ -93,7 +93,7 @@ gsl_sf_atanint_impl(const double x, gsl_sf_result * result)
   else if(ax < 1.0/GSL_SQRT_DBL_EPSILON) {
     const double t = 2.0 * (1.0/(x*x) - 0.5);
     gsl_sf_result result_c;
-    gsl_sf_cheb_eval_impl(&atanint_cs, t, &result_c);
+    cheb_eval_e(&atanint_cs, t, &result_c);
     result->val  = sgn * (0.5*M_PI*log(ax) + result_c.val/ax);
     result->err  = result_c.err/ax + fabs(result->val*GSL_DBL_EPSILON);
     result->err += GSL_DBL_EPSILON * fabs(result->val);
@@ -106,15 +106,11 @@ gsl_sf_atanint_impl(const double x, gsl_sf_result * result)
   }
 }
 
+/*-*-*-*-*-*-*-*-*-* Functions w/ Natural Prototypes *-*-*-*-*-*-*-*-*-*-*/
 
-/*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Error Handling *-*-*-*-*-*-*-*-*-*-*-*/
+#include "eval.h"
 
-int
-gsl_sf_atanint_e(const double x, gsl_sf_result * result)
+double gsl_sf_atanint(const double x)
 {
-  int status = gsl_sf_atanint_impl(x, result);
-  if(status != GSL_SUCCESS) {
-    GSL_ERROR("gsl_sf_atanint_e", status);
-  }
-  return status;
+  EVAL_RESULT(gsl_sf_atanint_e(x, &result));
 }
