@@ -18,14 +18,15 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: bessel_I0.c,v 1.27 2000/05/04 11:25:07 bjg Exp $
+ * RCS:     $Id: bessel_I0.c,v 1.29 2001/04/24 16:13:55 bjg Exp $
  */
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_chebyshev.h"
 #include "gsl_sf_bessel.h"
 
+#include "chebyshev.h"
+#include "cheb_eval.c"
 
 /*-*-*-*-*-*-*-*-*-*-*-* Private Section *-*-*-*-*-*-*-*-*-*-*-*/
 
@@ -68,12 +69,10 @@ static double bi0_data[12] = {
    .00000000000000053339,
    .00000000000000000245
 };
-static gsl_sf_cheb_series bi0_cs = {
+static cheb_series bi0_cs = {
   bi0_data,
   11,
   -1, 1,
-  (double *)0,
-  (double *)0,
   11
 };
 
@@ -100,12 +99,10 @@ static double ai0_data[21] = {
   -.00000000000000071,
    .00000000000000007
 };
-static gsl_sf_cheb_series ai0_cs = {
+static cheb_series ai0_cs = {
   ai0_data,
   20,
   -1, 1,
-  (double *)0,
-  (double *)0,
   13
 };
 
@@ -133,26 +130,23 @@ static double ai02_data[22] = {
   -.00000000000000027,
    .00000000000000003
 };
-static gsl_sf_cheb_series ai02_cs = {
+static cheb_series ai02_cs = {
   ai02_data,
   21,
   -1, 1,
-  (double *)0,
-  (double *)0,
   11
 };
 
 
-/*-*-*-*-*-*-*-*-*-*-*-* (semi)Private Implementations *-*-*-*-*-*-*-*-*-*-*-*/
+/*-*-*-*-*-*-*-*-*-*-*-* Functions with Error Codes *-*-*-*-*-*-*-*-*-*-*-*/
 
-int gsl_sf_bessel_I0_scaled_impl(const double x, gsl_sf_result * result)
+int gsl_sf_bessel_I0_scaled_e(const double x, gsl_sf_result * result)
 {
   double y = fabs(x);
 
-  if(result == 0) {
-    return GSL_EFAULT;
-  }
-  else if(y < 2.0 * GSL_SQRT_DBL_EPSILON) {
+  /* CHECK_POINTER(result) */
+
+  if(y < 2.0 * GSL_SQRT_DBL_EPSILON) {
     result->val = 1.0;
     result->err = 0.5*y*y;
     return GSL_SUCCESS;
@@ -160,7 +154,7 @@ int gsl_sf_bessel_I0_scaled_impl(const double x, gsl_sf_result * result)
   else if(y <= 3.0) {
     const double ey = exp(-y);
     gsl_sf_result c;
-    gsl_sf_cheb_eval_impl(&bi0_cs, y*y/4.5-1.0, &c);
+    cheb_eval_e(&bi0_cs, y*y/4.5-1.0, &c);
     result->val = ey * (2.75 + c.val);
     result->err = GSL_DBL_EPSILON * fabs(result->val) + ey * c.err;
     return GSL_SUCCESS;
@@ -168,7 +162,7 @@ int gsl_sf_bessel_I0_scaled_impl(const double x, gsl_sf_result * result)
   else if(y <= 8.0) {
     const double sy = sqrt(y);
     gsl_sf_result c;
-    gsl_sf_cheb_eval_impl(&ai0_cs, (48.0/y-11.0)/5.0, &c);
+    cheb_eval_e(&ai0_cs, (48.0/y-11.0)/5.0, &c);
     result->val  = (0.375 + c.val) / sy;
     result->err  = 2.0 * GSL_DBL_EPSILON * (0.375 + fabs(c.val)) / sy;
     result->err += c.err / sy;
@@ -178,7 +172,7 @@ int gsl_sf_bessel_I0_scaled_impl(const double x, gsl_sf_result * result)
   else {
     const double sy = sqrt(y);
     gsl_sf_result c;
-    gsl_sf_cheb_eval_impl(&ai02_cs, 16.0/y-1.0, &c);
+    cheb_eval_e(&ai02_cs, 16.0/y-1.0, &c);
     result->val = (0.375 + c.val) / sy;
     result->err  = 2.0 * GSL_DBL_EPSILON * (0.375 + fabs(c.val)) / sy;
     result->err += c.err / sy;
@@ -188,21 +182,20 @@ int gsl_sf_bessel_I0_scaled_impl(const double x, gsl_sf_result * result)
 }
 
 
-int gsl_sf_bessel_I0_impl(const double x, gsl_sf_result * result)
+int gsl_sf_bessel_I0_e(const double x, gsl_sf_result * result)
 {
   double y = fabs(x);
 
-  if(result == 0) {
-    return GSL_EFAULT;
-  }
-  else if(y < 2.0 * GSL_SQRT_DBL_EPSILON) {
+  /* CHECK_POINTER(result) */
+
+  if(y < 2.0 * GSL_SQRT_DBL_EPSILON) {
     result->val = 1.0;
     result->err = 0.5*y*y;
     return GSL_SUCCESS;
   }
   else if(y <= 3.0) {
     gsl_sf_result c;
-    gsl_sf_cheb_eval_impl(&bi0_cs, y*y/4.5-1.0, &c);
+    cheb_eval_e(&bi0_cs, y*y/4.5-1.0, &c);
     result->val  = 2.75 + c.val;
     result->err  = GSL_DBL_EPSILON * (2.75 + fabs(c.val));
     result->err += c.err;
@@ -212,7 +205,7 @@ int gsl_sf_bessel_I0_impl(const double x, gsl_sf_result * result)
   else if(y < GSL_LOG_DBL_MAX - 1.0) {
     const double ey = exp(y);
     gsl_sf_result b_scaled;
-    gsl_sf_bessel_I0_scaled_impl(x, &b_scaled);
+    gsl_sf_bessel_I0_scaled_e(x, &b_scaled);
     result->val  = ey * b_scaled.val;
     result->err  = ey * b_scaled.err + y*GSL_DBL_EPSILON*fabs(result->val);
     result->err += 2.0 * GSL_DBL_EPSILON * fabs(result->val);
@@ -221,27 +214,20 @@ int gsl_sf_bessel_I0_impl(const double x, gsl_sf_result * result)
   else {
     result->val = 0.0; /* FIXME: should be Inf */
     result->err = 0.0;
-    return GSL_EOVRFLW;
+    GSL_ERROR ("error", GSL_EOVRFLW);
   }
 }
 
+/*-*-*-*-*-*-*-*-*-* Functions w/ Natural Prototypes *-*-*-*-*-*-*-*-*-*-*/
 
-/*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Error Handling *-*-*-*-*-*-*-*-*-*-*-*/
+#include "eval.h"
 
-int gsl_sf_bessel_I0_scaled_e(const double x, gsl_sf_result * result)
+double gsl_sf_bessel_I0_scaled(const double x)
 {
-  int status = gsl_sf_bessel_I0_scaled_impl(x, result);  
-  if(status != GSL_SUCCESS) {
-    GSL_ERROR("gsl_sf_bessel_I0_scaled_e", status);
-  }
-  return status;
+  EVAL_RESULT(gsl_sf_bessel_I0_scaled_e(x, &result); ) 
 }
 
-int gsl_sf_bessel_I0_e(const double x, gsl_sf_result * result)
+double gsl_sf_bessel_I0(const double x)
 {
-  int status = gsl_sf_bessel_I0_impl(x, result);  
-  if(status != GSL_SUCCESS) {
-    GSL_ERROR("gsl_sf_bessel_I0_e", status);
-  }
-  return status;
+  EVAL_RESULT(gsl_sf_bessel_I0_e(x, &result); ) 
 }
