@@ -18,15 +18,15 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: bessel_olver.h,v 1.6 2000/05/04 11:25:07 bjg Exp $
+ * RCS:     $Id: bessel_olver.h,v 1.7 2001/04/23 09:38:29 bjg Exp $
  */
 #ifndef BESSEL_OLVER_H_
 #define BESSEL_OLVER_H_
 
 #include "gsl_sf_result.h"
 
-int gsl_sf_bessel_Jnu_asymp_Olver_impl(double nu, double x, gsl_sf_result * result);
-int gsl_sf_bessel_Ynu_asymp_Olver_impl(double nu, double x, gsl_sf_result * result);
+int gsl_sf_bessel_Jnu_asymp_Olver_e(double nu, double x, gsl_sf_result * result);
+int gsl_sf_bessel_Ynu_asymp_Olver_e(double nu, double x, gsl_sf_result * result);
 
 double gsl_sf_bessel_Olver_zofmzeta(double minus_zeta);
 
