@@ -18,7 +18,7 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: hyperg_2F0.c,v 1.10 2000/05/04 11:25:07 bjg Exp $
+ * RCS:     $Id: hyperg_2F0.c,v 1.11 2001/04/23 09:38:30 bjg Exp $
  */
 #include <config.h>
 #include <gsl/gsl_math.h>
@@ -28,14 +28,14 @@
 
 
 int
-gsl_sf_hyperg_2F0_impl(const double a, const double b, const double x, gsl_sf_result * result)
+gsl_sf_hyperg_2F0_e(const double a, const double b, const double x, gsl_sf_result * result)
 {
   if(x < 0.0) {
     /* Use "definition" 2F0(a,b,x) = (-1/x)^a U(a,1+a-b,-1/x).
      */
     gsl_sf_result U;
     double pre = pow(-1.0/x, a);
-    int stat_U = gsl_sf_hyperg_U_impl(a, 1.0+a-b, -1.0/x, &U);
+    int stat_U = gsl_sf_hyperg_U_e(a, 1.0+a-b, -1.0/x, &U);
     result->val = pre * U.val;
     result->err = GSL_DBL_EPSILON * fabs(result->val) + pre * U.err;
     return stat_U;
@@ -51,17 +51,15 @@ gsl_sf_hyperg_2F0_impl(const double a, const double b, const double x, gsl_sf_re
     /* return hyperg_2F0_series(a, b, x, -1, result, &prec); */
     result->val = 0.0;
     result->err = 0.0;
-    return GSL_EDOM;
+    GSL_ERROR ("error", GSL_EDOM);
   }
 }
 
+/*-*-*-*-*-*-*-*-*-* Functions w/ Natural Prototypes *-*-*-*-*-*-*-*-*-*-*/
 
-int
-gsl_sf_hyperg_2F0_e(const double a, const double b, const double x, gsl_sf_result * result)
+#include "eval.h"
+
+double gsl_sf_hyperg_2F0(const double a, const double b, const double x)
 {
-  int status = gsl_sf_hyperg_2F0_impl(a, b, x, result);
-  if(status != GSL_SUCCESS) {
-    GSL_ERROR("gsl_sf_hyperg_2F0_e", status);
-  }
-  return status;
+  EVAL_RESULT(gsl_sf_hyperg_2F0_e(a, b, x, &result));
 }
