@@ -18,14 +18,15 @@
  */
 
 /* Author:  G. Jungman
- * RCS:     $Id: transport.c,v 1.13 2000/05/04 11:25:08 bjg Exp $
+ * RCS:     $Id: transport.c,v 1.15 2001/04/24 16:13:56 bjg Exp $
  */
 #include <config.h>
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_errno.h>
-#include "gsl_sf_chebyshev.h"
 #include "gsl_sf_transport.h"
 
+#include "chebyshev.h"
+#include "cheb_eval.c"
 
 static double transport2_data[18] = {
    1.671760446434538503,
@@ -47,12 +48,10 @@ static double transport2_data[18] = {
    0.23e-16,
   -0.19e-17
 };
-static gsl_sf_cheb_series transport2_cs = {
+static cheb_series transport2_cs = {
   transport2_data,
   17,
   -1, 1,
-  (double *)0,
-  (double *)0,
   9
 };
 
@@ -76,12 +75,10 @@ static double transport3_data[18] = {
    0.219e-16,
   -0.19e-17
 };
-static gsl_sf_cheb_series transport3_cs = {
+static cheb_series transport3_cs = {
   transport3_data,
   17,
   -1, 1,
-  (double *)0,
-  (double *)0,
   9
 };
 
@@ -106,12 +103,10 @@ static double transport4_data[18] = {
   0.211e-16,
  -0.18e-17
 };
-static gsl_sf_cheb_series transport4_cs = {
+static cheb_series transport4_cs = {
   transport4_data,
   17,
   -1, 1,
-  (double *)0,
-  (double *)0,
   9
 };
 
@@ -136,12 +131,10 @@ static double transport5_data[18] = {
    0.21e-16,
   -0.18e-17
 };
-static gsl_sf_cheb_series transport5_cs = {
+static cheb_series transport5_cs = {
   transport5_data,
   17,
   -1, 1,
-  (double *)0,
-  (double *)0,
   9
 };
 
@@ -170,20 +163,19 @@ transport_sumexp(const int numexp, const int order, const double t, double x)
 }
 
 
-/*-*-*-*-*-*-*-*-*-*-*-* (semi)Private Implementations *-*-*-*-*-*-*-*-*-*-*-*/
+/*-*-*-*-*-*-*-*-*-*-*-* Functions with Error Codes *-*-*-*-*-*-*-*-*-*-*-*/
 
 int
-gsl_sf_transport_2_impl(const double x, gsl_sf_result * result)
+gsl_sf_transport_2_e(const double x, gsl_sf_result * result)
 {
   const double val_infinity = 3.289868133696452873;
 
-  if(result == 0) {
-    return GSL_EFAULT;
-  }
-  else if(x < 0.0) {
+  /* CHECK_POINTER(result) */
+
+  if(x < 0.0) {
     result->val = 0.0;
     result->err = 0.0;
-    return GSL_EDOM;
+    GSL_ERROR ("error", GSL_EDOM);
   }
   else if(x < 3.0*GSL_SQRT_DBL_EPSILON) {
     result->val = x;
@@ -193,7 +185,7 @@ gsl_sf_transport_2_impl(const double x, gsl_sf_result * result)
   else if(x <= 4.0) {
     double t = (x*x/8.0 - 0.5) - 0.5;
     gsl_sf_result result_c;
-    gsl_sf_cheb_eval_impl(&transport2_cs, t, &result_c);
+    cheb_eval_e(&transport2_cs, t, &result_c);
     result->val  = x * result_c.val;
     result->err  = x * result_c.err;
     result->err += 2.0 * GSL_DBL_EPSILON * fabs(result->val);
@@ -246,17 +238,16 @@ gsl_sf_transport_2_impl(const double x, gsl_sf_result * result)
 
 
 int
-gsl_sf_transport_3_impl(const double x, gsl_sf_result * result)
+gsl_sf_transport_3_e(const double x, gsl_sf_result * result)
 { 
   const double val_infinity = 7.212341418957565712;
 
-  if(result == 0) {
-    return GSL_EFAULT;
-  }
-  else if(x < 0.0) {
+  /* CHECK_POINTER(result) */
+
+  if(x < 0.0) {
     result->val = 0.0;
     result->err = 0.0;
-    return GSL_EDOM;
+    GSL_ERROR ("error", GSL_EDOM);
   }
   else if(x == 0.0) {
     result->val = 0.0;
@@ -267,7 +258,7 @@ gsl_sf_transport_3_impl(const double x, gsl_sf_result * result)
     result->val = 0.5*x*x;
     result->err = 2.0 * GSL_DBL_EPSILON * result->val;
     if(result->val == 0.0)
-      return GSL_EUNDRFLW;
+      GSL_ERROR ("error", GSL_EUNDRFLW);
     else
       return GSL_SUCCESS;
   }
@@ -275,7 +266,7 @@ gsl_sf_transport_3_impl(const double x, gsl_sf_result * result)
     const double x2 = x*x;
     const double t = (x2/8.0 - 0.5) - 0.5;
     gsl_sf_result result_c;
-    gsl_sf_cheb_eval_impl(&transport3_cs, t, &result_c);
+    cheb_eval_e(&transport3_cs, t, &result_c);
     result->val  = x2 * result_c.val;
     result->err  = x2 * result_c.err;
     result->err += GSL_DBL_EPSILON * fabs(result->val);
@@ -328,17 +319,16 @@ gsl_sf_transport_3_impl(const double x, gsl_sf_result * result)
 
 
 int
-gsl_sf_transport_4_impl(const double x, gsl_sf_result * result)
+gsl_sf_transport_4_e(const double x, gsl_sf_result * result)
 {
   const double val_infinity = 25.97575760906731660;
 
-  if(result == 0) {
-    return GSL_EFAULT;
-  }
-  else if(x < 0.0) {
+  /* CHECK_POINTER(result) */
+
+  if(x < 0.0) {
     result->val = 0.0;
     result->err = 0.0;
-    return GSL_EDOM;
+    GSL_ERROR ("error", GSL_EDOM);
   }
   else if(x == 0.0) {
     result->val = 0.0;
@@ -349,7 +339,7 @@ gsl_sf_transport_4_impl(const double x, gsl_sf_result * result)
     result->val = x*x*x/3.0;
     result->err = 3.0 * GSL_DBL_EPSILON * result->val;
     if(result->val == 0.0)
-      return GSL_EUNDRFLW;
+      GSL_ERROR ("error", GSL_EUNDRFLW);
     else
       return GSL_SUCCESS;
   }
@@ -357,7 +347,7 @@ gsl_sf_transport_4_impl(const double x, gsl_sf_result * result)
     const double x2 = x*x;
     const double t = (x2/8.0 - 0.5) - 0.5;
     gsl_sf_result result_c;
-    gsl_sf_cheb_eval_impl(&transport4_cs, t, &result_c);
+    cheb_eval_e(&transport4_cs, t, &result_c);
     result->val  = x2*x * result_c.val;
     result->err  = x2*x * result_c.err;
     result->err += 2.0 * GSL_DBL_EPSILON * fabs(result->val);
@@ -410,17 +400,16 @@ gsl_sf_transport_4_impl(const double x, gsl_sf_result * result)
 
 
 int
-gsl_sf_transport_5_impl(const double x, gsl_sf_result * result)
+gsl_sf_transport_5_e(const double x, gsl_sf_result * result)
 {
   const double val_infinity = 124.4313306172043912;
 
-  if(result == 0) {
-    return GSL_EFAULT;
-  }
-  else if(x < 0.0) {
+  /* CHECK_POINTER(result) */
+
+  if(x < 0.0) {
     result->val = 0.0;
     result->err = 0.0;
-    return GSL_EDOM;
+    GSL_ERROR ("error", GSL_EDOM);
   }
   else if(x == 0.0) {
     result->val = 0.0;
@@ -431,7 +420,7 @@ gsl_sf_transport_5_impl(const double x, gsl_sf_result * result)
     result->val = x*x*x*x/4.0;
     result->err = 4.0 * GSL_DBL_EPSILON * result->val;
     if(result->val == 0.0)
-      return GSL_EUNDRFLW;
+      GSL_ERROR ("error", GSL_EUNDRFLW);
     else
       return GSL_SUCCESS;
   }
@@ -439,7 +428,7 @@ gsl_sf_transport_5_impl(const double x, gsl_sf_result * result)
     const double x2 = x*x;
     const double t = (x2/8.0 - 0.5) - 0.5;
     gsl_sf_result result_c;
-    gsl_sf_cheb_eval_impl(&transport5_cs, t, &result_c);
+    cheb_eval_e(&transport5_cs, t, &result_c);
     result->val  = x2*x2 * result_c.val;
     result->err  = x2*x2 * result_c.err;
     result->err += 2.0 * GSL_DBL_EPSILON * fabs(result->val);
@@ -490,41 +479,26 @@ gsl_sf_transport_5_impl(const double x, gsl_sf_result * result)
   }
 }
 
+/*-*-*-*-*-*-*-*-*-* Functions w/ Natural Prototypes *-*-*-*-*-*-*-*-*-*-*/
 
-/*-*-*-*-*-*-*-*-*-*-*-* Functions w/ Error Handling *-*-*-*-*-*-*-*-*-*-*-*/
+#include "eval.h"
 
-int gsl_sf_transport_2_e(const double x, gsl_sf_result * result)
+double gsl_sf_transport_2(const double x)
 {
-  int status = gsl_sf_transport_2_impl(x, result);
-  if(status != GSL_SUCCESS) {
-    GSL_ERROR("gsl_sf_transport_2_e", status);
-  }
-  return status;
+  EVAL_RESULT(gsl_sf_transport_2_e(x, &result));
 }
 
-int gsl_sf_transport_3_e(const double x, gsl_sf_result * result)
+double gsl_sf_transport_3(const double x)
 {
-  int status = gsl_sf_transport_3_impl(x, result);
-  if(status != GSL_SUCCESS) {
-    GSL_ERROR("gsl_sf_transport_3_e", status);
-  }
-  return status;
+  EVAL_RESULT(gsl_sf_transport_3_e(x, &result));
 }
 
-int gsl_sf_transport_4_e(const double x, gsl_sf_result * result)
+double gsl_sf_transport_4(const double x)
 {
-  int status = gsl_sf_transport_4_impl(x, result);
-  if(status != GSL_SUCCESS) {
-    GSL_ERROR("gsl_sf_transport_4_e", status);
-  }
-  return status;
+  EVAL_RESULT(gsl_sf_transport_4_e(x, &result));
 }
 
-int gsl_sf_transport_5_e(const double x, gsl_sf_result * result)
+double gsl_sf_transport_5(const double x)
 {
-  int status = gsl_sf_transport_5_impl(x, result);
-  if(status != GSL_SUCCESS) {
-    GSL_ERROR("gsl_sf_transport_5_e", status);
-  }
-  return status;
+  EVAL_RESULT(gsl_sf_transport_5_e(x, &result));
 }
