@@ -1,10 +1,32 @@
+/* statistics/test.c
+ * 
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000 Jim Davies, Brian Gough
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 #include <string.h>
 #include <stdlib.h>
 #include <math.h>
 
-#include <gsl_test.h>
-#include <gsl_statistics.h>
+#include <gsl/gsl_test.h>
+#include <gsl/gsl_sort.h>
+#include <gsl/gsl_sort_vector.h>
+#include <gsl/gsl_statistics.h>
+#include <gsl/gsl_ieee_utils.h>
 
 /* Test program for mean.c.  JimDavies 7.96 */
 
@@ -78,19 +100,27 @@
 int
 main (void)
 {
-  test_func ();
-  test_float_func ();
-  test_long_double_func ();
+  size_t s1, s2;
 
-  test_ulong_func ();
-  test_long_func ();
-  test_uint_func ();
-  test_int_func ();
-  test_ushort_func ();
-  test_short_func ();
-  test_uchar_func ();
-  test_char_func ();
+  gsl_ieee_env_setup ();
 
+  for (s1 = 1; s1 < 4 ; s1++) 
+    {
+      s2 = (s1 < 3) ? 1 : (s1 - 1) ;
+
+      test_func (s1,s2);
+      test_float_func (s1,s2);
+      test_long_double_func (s1,s2);
+      
+      test_ulong_func (s1,s2);
+      test_long_func (s1,s2);
+      test_uint_func (s1,s2);
+      test_int_func (s1,s2);
+      test_ushort_func (s1,s2);
+      test_short_func (s1,s2);
+      test_uchar_func (s1,s2);
+      test_char_func (s1,s2);
+    }
 
   return gsl_test_summary ();
 }
