@@ -72,6 +72,10 @@ int gsl_vector_complex_view_from_vector (gsl_vector_complex *v,
                                                gsl_vector_complex *base,
                                                size_t offset, size_t n, size_t stride);
 
+int gsl_vector_complex_view_from_array (gsl_vector_complex *v, 
+                                              double *base,
+                                              size_t offset, size_t n, size_t stride);
+
 gsl_vector_complex gsl_vector_complex_subvector (gsl_vector_complex *v, size_t i, size_t n);
 gsl_vector_complex gsl_vector_complex_subvector_with_stride (gsl_vector_complex *v, size_t i, size_t n, size_t stride);
 
