@@ -72,6 +72,10 @@ int gsl_vector_complex_float_view_from_vector (gsl_vector_complex_float *v,
                                                gsl_vector_complex_float *base,
                                                size_t offset, size_t n, size_t stride);
 
+int gsl_vector_complex_float_view_from_array (gsl_vector_complex_float *v, 
+                                              float *base,
+                                              size_t offset, size_t n, size_t stride);
+
 gsl_vector_complex_float gsl_vector_complex_float_subvector (gsl_vector_complex_float *v, size_t i, size_t n);
 gsl_vector_complex_float gsl_vector_complex_float_subvector_with_stride (gsl_vector_complex_float *v, size_t i, size_t n, size_t stride);
 
