@@ -44,6 +44,7 @@ struct gsl_vector_complex_long_double_struct
   size_t stride;
   long double *data;
   gsl_block_complex_long_double *block;
+  int owner;
 };
 
 typedef struct gsl_vector_complex_long_double_struct gsl_vector_complex_long_double;
@@ -51,6 +52,8 @@ typedef struct gsl_vector_complex_long_double_struct gsl_vector_complex_long_dou
 gsl_vector_complex_long_double *gsl_vector_complex_long_double_alloc (const size_t n);
 gsl_vector_complex_long_double *gsl_vector_complex_long_double_calloc (const size_t n);
 
+gsl_vector_complex_long_double gsl_vector_complex_long_double_view (long double * v, size_t n);
+
 gsl_vector_complex_long_double 
 *gsl_vector_complex_long_double_alloc_from_block (gsl_block_complex_long_double * b, 
                                             const size_t offset, 
@@ -69,9 +72,16 @@ int gsl_vector_complex_long_double_view_from_vector (gsl_vector_complex_long_dou
                                                gsl_vector_complex_long_double *base,
                                                size_t offset, size_t n, size_t stride);
 
+int gsl_vector_complex_long_double_view_from_array (gsl_vector_complex_long_double *v, 
+                                              long double *base,
+                                              size_t offset, size_t n, size_t stride);
+
 gsl_vector_complex_long_double gsl_vector_complex_long_double_subvector (gsl_vector_complex_long_double *v, size_t i, size_t n);
 gsl_vector_complex_long_double gsl_vector_complex_long_double_subvector_with_stride (gsl_vector_complex_long_double *v, size_t i, size_t n, size_t stride);
 
+const gsl_vector_complex_long_double gsl_vector_complex_long_double_const_subvector (const gsl_vector_complex_long_double *v, size_t i, size_t n);
+const gsl_vector_complex_long_double gsl_vector_complex_long_double_const_subvector_with_stride (const gsl_vector_complex_long_double *v, size_t i, size_t n, size_t stride);
+
 
 gsl_complex_long_double 
 *gsl_vector_complex_long_double_ptr (const gsl_vector_complex_long_double * v, size_t i);
@@ -119,7 +129,7 @@ gsl_vector_complex_long_double_get (const gsl_vector_complex_long_double * v,
   if (i >= v->size)
     {
       const gsl_complex_long_double zero = {{0, 0}};
-      GSL_ERROR_RETURN ("index out of range", GSL_EINVAL, zero);
+      GSL_ERROR_VAL ("index out of range", GSL_EINVAL, zero);
     }
 #endif
   return *GSL_COMPLEX_LONG_DOUBLE_AT (v, i);
@@ -133,7 +143,7 @@ gsl_vector_complex_long_double_set (gsl_vector_complex_long_double * v,
 #ifndef GSL_RANGE_CHECK_OFF
   if (i >= v->size)
     {
-      GSL_ERROR_RETURN_NOTHING ("index out of range", GSL_EINVAL);
+      GSL_ERROR_VOID ("index out of range", GSL_EINVAL);
     }
 #endif
   *GSL_COMPLEX_LONG_DOUBLE_AT (v, i) = z;
