@@ -68,6 +68,10 @@ int gsl_vector_view_from_vector (gsl_vector *v,
                                        gsl_vector *base,
                                        size_t offset, size_t n, size_t stride);
 
+int gsl_vector_view_from_array (gsl_vector *v, 
+                                      double *base,
+                                      size_t offset, size_t n, size_t stride);
+
 gsl_vector gsl_vector_subvector (gsl_vector *v, size_t i, size_t n);
 gsl_vector gsl_vector_subvector_with_stride (gsl_vector *v, size_t i, size_t n, size_t stride);
 
