@@ -42,6 +42,7 @@ struct gsl_vector_float_struct
   size_t stride;
   float *data;
   gsl_block_float *block;
+  int owner;
 };
 
 typedef struct gsl_vector_float_struct gsl_vector_float;
@@ -61,13 +62,22 @@ gsl_vector_float *gsl_vector_float_alloc_from_vector (gsl_vector_float * v,
 
 void gsl_vector_float_free (gsl_vector_float * v);
 
+gsl_vector_float gsl_vector_float_view (float *v, size_t n);
+
 int gsl_vector_float_view_from_vector (gsl_vector_float *v, 
                                        gsl_vector_float *base,
                                        size_t offset, size_t n, size_t stride);
 
+int gsl_vector_float_view_from_array (gsl_vector_float *v, 
+                                      float *base,
+                                      size_t offset, size_t n, size_t stride);
+
 gsl_vector_float gsl_vector_float_subvector (gsl_vector_float *v, size_t i, size_t n);
 gsl_vector_float gsl_vector_float_subvector_with_stride (gsl_vector_float *v, size_t i, size_t n, size_t stride);
 
+const gsl_vector_float gsl_vector_float_const_subvector (const gsl_vector_float *v, size_t i, size_t n);
+const gsl_vector_float gsl_vector_float_const_subvector_with_stride (const gsl_vector_float *v, size_t i, size_t n, size_t stride);
+
 float *gsl_vector_float_ptr (const gsl_vector_float * v, const size_t i);
 float gsl_vector_float_get (const gsl_vector_float * v, const size_t i);
 void gsl_vector_float_set (gsl_vector_float * v, const size_t i, float x);
@@ -118,7 +128,7 @@ gsl_vector_float_get (const gsl_vector_float * v, const size_t i)
 #ifndef GSL_RANGE_CHECK_OFF
   if (i >= v->size)
     {
-      GSL_ERROR_RETURN ("index out of range", GSL_EINVAL, 0);
+      GSL_ERROR_VAL ("index out of range", GSL_EINVAL, 0);
     }
 #endif
   return v->data[i * v->stride];
@@ -131,7 +141,7 @@ gsl_vector_float_set (gsl_vector_float * v, const size_t i, float x)
 #ifndef GSL_RANGE_CHECK_OFF
   if (i >= v->size)
     {
-      GSL_ERROR_RETURN_NOTHING ("index out of range", GSL_EINVAL);
+      GSL_ERROR_VOID ("index out of range", GSL_EINVAL);
     }
 #endif
   v->data[i * v->stride] = x;
