@@ -68,6 +68,10 @@ int gsl_vector_long_view_from_vector (gsl_vector_long *v,
                                        gsl_vector_long *base,
                                        size_t offset, size_t n, size_t stride);
 
+int gsl_vector_long_view_from_array (gsl_vector_long *v, 
+                                      long *base,
+                                      size_t offset, size_t n, size_t stride);
+
 gsl_vector_long gsl_vector_long_subvector (gsl_vector_long *v, size_t i, size_t n);
 gsl_vector_long gsl_vector_long_subvector_with_stride (gsl_vector_long *v, size_t i, size_t n, size_t stride);
 
