@@ -68,6 +68,10 @@ int gsl_vector_long_double_view_from_vector (gsl_vector_long_double *v,
                                        gsl_vector_long_double *base,
                                        size_t offset, size_t n, size_t stride);
 
+int gsl_vector_long_double_view_from_array (gsl_vector_long_double *v, 
+                                      long double *base,
+                                      size_t offset, size_t n, size_t stride);
+
 gsl_vector_long_double gsl_vector_long_double_subvector (gsl_vector_long_double *v, size_t i, size_t n);
 gsl_vector_long_double gsl_vector_long_double_subvector_with_stride (gsl_vector_long_double *v, size_t i, size_t n, size_t stride);
 
