@@ -68,6 +68,10 @@ int gsl_vector_ulong_view_from_vector (gsl_vector_ulong *v,
                                        gsl_vector_ulong *base,
                                        size_t offset, size_t n, size_t stride);
 
+int gsl_vector_ulong_view_from_array (gsl_vector_ulong *v, 
+                                      unsigned long *base,
+                                      size_t offset, size_t n, size_t stride);
+
 gsl_vector_ulong gsl_vector_ulong_subvector (gsl_vector_ulong *v, size_t i, size_t n);
 gsl_vector_ulong gsl_vector_ulong_subvector_with_stride (gsl_vector_ulong *v, size_t i, size_t n, size_t stride);
 
